package net.wanji.common.utils.geo;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.*;
import org.locationtech.jts.io.ParseException;
import org.locationtech.jts.io.WKBWriter;
import org.locationtech.jts.io.WKTReader;
import org.locationtech.jts.linearref.LengthLocationMap;
import org.locationtech.jts.linearref.LinearLocation;
import org.locationtech.jts.linearref.LocationIndexedLine;
import org.locationtech.jts.operation.buffer.BufferOp;
import org.locationtech.jts.operation.buffer.BufferParameters;
import org.locationtech.jts.operation.buffer.OffsetCurveBuilder;
import org.apache.commons.lang3.StringUtils;
import org.geotools.geojson.geom.GeometryJSON;
import org.locationtech.jts.operation.linemerge.LineMerger;

import java.io.IOException;
import java.io.StringReader;
import java.io.StringWriter;
import java.util.*;

import static org.locationtech.jts.geom.Geometry.TYPENAME_MULTILINESTRING;

/**
 * @Author xiaodong.zheng
 * @Date 2020/3/23
 * @description
 */
@Slf4j
public class GeometryUtils {
    private static GeometryFactory geometryFactory = new GeometryFactory();
    private static WKTReader reader = new WKTReader( geometryFactory );

    /**
     * 判断两个几何图形相交
     * @param wkt1
     * @param wkt2
     * @return
     * @throws ParseException
     */
    public synchronized static boolean intersects(String wkt1,String wkt2) throws ParseException {
        Geometry geometry1 = reader.read(wkt1);
        Geometry geometry2 = reader.read(wkt2);
        return  geometry1.intersects(geometry2);
    }

    /**
     *  根据wkt 获取面积
     * @param wkt1
     * @return
     * @throws ParseException
     */
    public  static Double getAreaByWkt(String wkt1){
        double area  = 0;
        try {
            Geometry geometry1  = reader.read(wkt1);
            area = geometry1.getArea();
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return area * 10000;
    }



    public  static String convertWktString(double longitude ,double latitude) throws ParseException {
        Coordinate coordinate = new Coordinate(longitude, latitude);
        Point point =  geometryFactory.createPoint(coordinate);
        return  point.toText();
    }

    /**
     * geometry转geoJson
     * @param geometry
     * @return
     */
    public static JSONObject convertToGeoJson(Geometry geometry){
        GeometryJSON geometryJSON = new GeometryJSON();
        return GeometryUtils.convertGeomString2Geojson(geometryJSON, geometry);
    }

    /**
     *线偏移一定距离
     * @param wkt
     * @param distance 偏移的距离 偏移线将在左侧显示正值，否则在右侧
     * @return
     */
    public static LineString offSetLine(String wkt, double distance){
        if (StringUtils.isNotBlank(wkt) && Optional.ofNullable(distance).isPresent()){
            distance = distance /100000;
            Geometry geometry = null;
            try {
                geometry = reader.read(wkt);
                geometry.setSRID(4326);
                LineString lineString = (LineString) geometry;
                BufferParameters bufferParameters = new BufferParameters(BufferParameters.DEFAULT_QUADRANT_SEGMENTS);
                PrecisionModel precisionModel = new PrecisionModel(PrecisionModel.FLOATING);
                OffsetCurveBuilder offsetCurveBuilder = new OffsetCurveBuilder(precisionModel, bufferParameters);
                Coordinate[] coordinates  = offsetCurveBuilder.getOffsetCurve(lineString.getCoordinates(),distance);
                return geometryFactory.createLineString(coordinates);
            } catch (ParseException e) {
            }
        }
        return null;
    }

    public static LineString offSetSmothLine(String wkt, double distance){
        if (StringUtils.isNotBlank(wkt) && Optional.ofNullable(distance).isPresent()){
            distance = distance /100000;
            Geometry geometry = null;
            try {
                geometry = reader.read(wkt);
                geometry.setSRID(4326);
                LineString lineString = (LineString) geometry;
                BufferParameters bufferParameters = new BufferParameters(4);
                bufferParameters.setJoinStyle(1);
                PrecisionModel precisionModel = new PrecisionModel(PrecisionModel.FLOATING);
                OffsetCurveBuilder offsetCurveBuilder = new OffsetCurveBuilder(precisionModel, bufferParameters);
                Coordinate[] coordinates  = offsetCurveBuilder.getOffsetCurve(lineString.getCoordinates(),distance);
                return geometryFactory.createLineString(coordinates);
            } catch (ParseException e) {
            }
        }
        return null;
    }

    /**
     *将 线缓冲一定的距离 得到面
     * @param wkt
     * @param distance 缓冲的距离
     * @return
     */
    public static Geometry bufferLine(String wkt,double distance){
        if (StringUtils.isNotBlank(wkt) && Optional.ofNullable(distance).isPresent()){
            distance = distance /100000;
            Geometry geometry = null;
            try {
                geometry = reader.read(wkt);
                geometry.setSRID(4326);
                BufferOp bufOp = new BufferOp(geometry);
                bufOp.setEndCapStyle(BufferParameters.CAP_FLAT);
                Geometry bg = bufOp.getResultGeometry(distance);
                return bg;
            } catch (ParseException e) {
            }
        }

        return null;
    }

    /**
     *多线段合并
     * */
    public static String mergerLine(List<String> lineStr) throws IOException,ParseException{
        LineMerger lineMerger = new LineMerger();
        List<Geometry> list = new ArrayList<Geometry>();
        WKTReader reader = new WKTReader( geometryFactory );
        for(String line:lineStr){
            if(StringUtils.isNotEmpty(line)){
                LineString lineGeom = (LineString) reader.read(line);
                list.add(lineGeom);
            }
        }
        lineMerger.add(list);
        Collection<Geometry> mergerLineStrings = lineMerger.getMergedLineStrings();
        for (Geometry g : mergerLineStrings) {
            GeometryJSON geometryJSON = new GeometryJSON(12);
            StringWriter writer = new StringWriter();
            geometryJSON.write(g, writer);
            return writer.toString();
        }
        return null;
    }

    public static boolean valid(JSONObject jsonObject) throws IOException {
        GeometryJSON geometryJSON = new GeometryJSON(12);
        StringReader stringReader = new StringReader(jsonObject.toString());
        Geometry geometry1  = geometryJSON.read(stringReader);
        return geometry1.isValid();
    }

    public static boolean validGeojson(String geojson) {
        GeometryJSON geometryJSON = new GeometryJSON(12);
        Geometry geometry1 = null;
        try {
            StringReader stringReader = new StringReader(geojson);
            geometry1  = geometryJSON.read(stringReader);
        } catch (IOException e) {
            e.printStackTrace();
        }
        return Objects.nonNull(geometry1)&&!geometry1.isEmpty();
    }

    public static boolean validWkt(String wkt){
        Geometry geometry1 = null;
        try {
            geometry1 = reader.read(wkt);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return geometry1.isValid();
    }

    public static Point getCenterByWkt(String wkt) throws IOException {
        Geometry geometry1 = null;
        Point point = null;
        try {
            geometry1 = reader.read(wkt);
            point =  geometry1.getCentroid();
        } catch (ParseException e) {
            e.printStackTrace();
        }
        return point;
    }

    public static Point getCenterByGeoJson(String jsonObject) throws IOException {
        Geometry geometry1 = null;
        Point point = null;
        try {
            GeometryJSON geometryJSON = new GeometryJSON(12);
            StringReader stringReader = new StringReader(jsonObject);
            geometry1  = geometryJSON.read(stringReader);
            point =  geometry1.getCentroid();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return point;
    }


    /**
     * geometry转geoJson
     * @param
     * @return
     */
    public static String  polygonToMultipolygon(String polygonWkt) {
//        GeometryJSON geometryJSON = new GeometryJSON();
        Polygon polygon = null;
        try {
            polygon = (Polygon) reader.read(polygonWkt);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        Polygon[] polygons = new Polygon[]{polygon};
        MultiPolygon multiPolygon = geometryFactory.createMultiPolygon(polygons);
        return multiPolygon.toString();
    }


    /**
     * wkt to wkb
     * @param wkt
     * @return
     * @throws ParseException
     */
    public static String encodeWkt2Wkb(String wkt,int srid) throws ParseException {
        WKBWriter wkbWriter = new WKBWriter();
        Geometry geometry=reader.read(wkt);
        geometry.setSRID(srid);
        byte[] bytes = wkbWriter.write(geometry);
        String wkb =WKBWriter.toHex(bytes);
        return wkb;
    }

    /**
     * GeometryJSON 转json string
     * @param g
     * @param geometry
     * @return
     */
    public static JSONObject convertGeomString2Geojson(GeometryJSON g, Geometry geometry){
        JSONObject obj = null;
        try {
            StringWriter writer = new StringWriter();
            g.write(geometry, writer);
            obj = JSONObject.parseObject(writer.toString());
        } catch (IOException e) {
            log.error(e.getMessage());
        }
        return obj;
    }

    public static String convertWkt2Geojson(String wkt){
        GeometryJSON geometryJSON = new GeometryJSON(20);
        StringWriter writer = new StringWriter();
        try {
            WKTReader reader = new WKTReader(geometryFactory );
            Geometry geometry =  reader.read(wkt);
            geometryJSON.write(geometry, writer);
        } catch (Exception e) {
            log.error(e.getMessage());
        }
        return writer.toString();
    }

    /**
     * GeoJSON 转 wkt
     * @param geojson
     * @return String
     */
    public static String convertGeojson2Wkt(String geojson){
        String wkt = "";
        try {
            JSONObject obj = JSON.parseObject(geojson);
            GeometryJSON g = new GeometryJSON(20);
            Geometry geometry = g.read(new StringReader(obj.toJSONString()));
            wkt = geometry.toText();

        } catch (IOException e) {
            log.error(e.getMessage());
        }
        return wkt;
    }

    /**
     *  多线转单线
     * @param wkt
     * @return
     * @throws ParseException
     */
    public static String convertMulit2Line(String wkt) throws ParseException{
        WKTReader reader = new WKTReader( geometryFactory );
        Geometry lineGeom =  reader.read(wkt);
        if(TYPENAME_MULTILINESTRING.equals(lineGeom.getGeometryType())){
            lineGeom=geometryFactory.createLineString(lineGeom.getCoordinates());
        }
        return lineGeom.toText();
    }

    /**
     * 根据长度返回线上指定距离的线段
     * @param lineString
     * @param distance
     * @return
     */
    public static Geometry getLineDistance(Geometry lineString,double distance){
        distance = distance /100000;
        LocationIndexedLine locationIndexedLine=new LocationIndexedLine(lineString);
        LinearLocation linearLocation= LengthLocationMap.getLocation(lineString,distance);
        LinearLocation startLocation= locationIndexedLine.getStartIndex();
        return  locationIndexedLine.extractLine(startLocation,linearLocation);
    }

    /**
     * 获取geometry
     * @param wkt
     * @return
     * @throws ParseException
     */
    public static Geometry getGeometry(String wkt) throws ParseException {
        WKTReader wktReader = new WKTReader(geometryFactory);
        Geometry geomtry = wktReader.read(wkt);
        return geomtry;
    }

    public static void main(String[] args) throws Exception {
        String lineString = "LINESTRING(118.12734212 37.49569661, 118.12701199 37.49567925, 118.12656873 37.49565999, 118.12540011 37.49561062, 118.12005371 37.49538845)";
//        Double distance = 10.0;
//        Double width = 5.0;
//
//        //道路中心线平移
//        LineString lineString1 = GeometryUtils.offSetLine(lineString, distance);
//
//        //通过平移道路中心线，根据道路宽度的一半缓冲，得到道路中心面
//        Geometry geometry = GeometryUtils.bufferLine(lineString1.toString(), width / 2);
//
//        JSONObject object = new JSONObject();
//        object.put("lineGeom",lineString1.toString());
//        object.put("polygonGeom",geometry.toString());

//        String wkt = "POLYGON((119.039890136719 37.3044664171007, 119.035866427951 37.3061189778646, 119.030822753906 37.3081287977431, 119.02196234809 37.3102964952257, 119.010303548177 37.3132101779514, 119.001206325955 37.3187581380208, 118.993556043837 37.3273980034722, 118.986952853733 37.3395109049479, 118.98312906901 37.350016547309, 118.981622721354 37.358792046441, 118.981431206597 37.3598250325521, 118.963889702691 37.3569094509549, 118.958857421875 37.3558213975694, 118.950144856771 37.3536802842882, 118.944419759115 37.35193359375, 118.940392252604 37.3509676106771, 118.936956922743 37.3501508246528, 118.932513834635 37.3500716145833, 118.928871527778 37.3502501085069, 118.926707085503 37.3505520290799, 118.922336425781 37.3517125108507, 118.916750488281 37.3539499240451, 118.914483506944 37.3551255967882, 118.908639865451 37.3574085828993, 118.906834038628 37.3583506944444, 118.905965983073 37.3591799587674, 118.904837510851 37.358359375, 118.903457302517 37.3571698676215, 118.903005642361 37.3563709852431, 118.902918836806 37.3555590820312, 118.90298828125 37.3540828450521, 118.902658148872 37.3513690863715, 118.902484266493 37.3497970920139, 118.901789822049 37.3483732096354, 118.900314127604 37.345625, 118.89896891276 37.3443617078993, 118.897406955295 37.3432638888889, 118.895307074653 37.3423182508681, 118.89095187717 37.3406968858507, 118.888636067708 37.3398689778646, 118.887005208333 37.3388671875, 118.885860460069 37.3376871744792, 118.884594184028 37.335530327691, 118.882330457899 37.3315983072917, 118.881324598524 37.3301185438368, 118.880119357639 37.3290896267361, 118.879157172309 37.3287369791667, 118.878136664497 37.3287182617187, 118.877050238715 37.3288772243924, 118.875862901476 37.3294300672743, 118.873635253906 37.3307180447049, 118.871199815538 37.3315766059028, 118.869665798611 37.3317523871528, 118.866708170573 37.331530219184, 118.864697265625 37.3312136501736, 118.862508138021 37.3308596462674, 118.860879177517 37.3308884006076, 118.859770236545 37.3309073893229, 118.857517632378 37.3312543402778, 118.855888943142 37.3315825737847, 118.851965060764 37.332848578559, 118.85049235026 37.3332071940104, 118.850163302951 37.3332381184896, 118.835256890191 37.3326969401042, 118.831861979167 37.3325729709201, 118.825799153646 37.3325105794271, 118.821823730469 37.3322789171007, 118.819129774306 37.3314718967014, 118.818324110243 37.331243218316, 118.816892903646 37.3305124240451, 118.814613172743 37.3298285590278, 118.812798936632 37.3295857747396, 118.807331000434 37.3297667100694, 118.803064507378 37.329625922309, 118.798454047309 37.3290182834201, 118.794315863715 37.3284282769097, 118.791940917969 37.3281966145833, 118.788820529514 37.3284654405382, 118.784624565972 37.3289474826389, 118.781277669271 37.3295195855035, 118.777600911458 37.3298787434896, 118.773350965712 37.3298426649306, 118.768753255208 37.3294458007813, 118.763122558594 37.3288636610243, 118.759388834635 37.3283333333333, 118.757423502604 37.3280780707465, 118.75485921224 37.3278209092882, 118.75100124783 37.3278206380208, 118.748912489149 37.3277954101562, 118.747609592014 37.327451171875, 118.746060926649 37.3267130533854, 118.742864854601 37.3243519422743, 118.740652126736 37.3233430989583, 118.738021375868 37.3229728190104, 118.734480251736 37.3226996527778, 118.730298936632 37.3223027886285, 118.728478732639 37.3220798068576, 118.725199652778 37.326569281684, 118.721975097656 37.3301087782118, 118.720949164497 37.3316663953993, 118.719454210069 37.3341178385417, 118.71743733724 37.3370505099826, 118.701199544271 37.3372254774306, 118.701190863715 37.3380938042535, 118.696876085069 37.3381079101563, 118.696101616753 37.3381065538194, 118.697014973958 37.3370705837674, 118.695701497396 37.3371158854167, 118.695657823351 37.3363427734375, 118.687409667969 37.3364927842882, 118.684921332465 37.3365793185764, 118.684851616753 37.3352547200521, 118.676637641059 37.3353214518229, 118.681292317708 37.3295640733507, 118.677707248264 37.3294398328993, 118.677681206597 37.3305471462674, 118.678953450521 37.330612250434, 118.67879828559 37.3322688802083, 118.67656765408 37.3322992621528, 118.676524251302 37.3311181640625, 118.672434624566 37.3311146375868, 118.672356228299 37.3293123372396, 118.676880696615 37.3295079210069, 118.679577636719 37.3255007595486, 118.666891547309 37.3253550889757, 118.663420681424 37.3303854709201, 118.66208062066 37.3294930013021, 118.661393500434 37.3291965060764, 118.659601508247 37.3312253146701, 118.639752604167 37.3213538953993, 118.638065321181 37.3168052842882, 118.636952039931 37.3118145073785, 118.635552300347 37.3113351779514, 118.63469156901 37.3113384331597, 118.630736490885 37.3113425021701, 118.623106282552 37.3112961154514, 118.620291341146 37.3112331814236, 118.602689615885 37.3112906901042, 118.602368977865 37.3144487847222, 118.599557020399 37.3147531467014, 118.59567843967 37.3154009331597, 118.595486653646 37.3057524956597, 118.585061306424 37.3056236436632, 118.585200737847 37.3140044487847, 118.58373562283 37.3139925130208, 118.583751898872 37.3056073676215, 118.580188802083 37.3055631510417, 118.579460720486 37.3055419921875, 118.579635687934 37.3192941623264, 118.57156765408 37.3211797417535, 118.566794433594 37.3221508789062, 118.566871744792 37.3155767144097, 118.562047526042 37.3157194010417, 118.562073567708 37.314342719184, 118.562176649306 37.3079418945312, 118.562193739149 37.3057405598958, 118.562202419705 37.3050716145833, 118.555084364149 37.2990842013889, 118.554452582465 37.2990161132812, 118.554574652778 37.3081868489583, 118.554739583333 37.3116691080729, 118.553908420139 37.3118573676215, 118.551190592448 37.3124452039931, 118.550289171007 37.2993636067708, 118.552530653212 37.298994140625, 118.553586697049 37.2988354492187, 118.553915744358 37.2988389756944, 118.554755588108 37.2989154730903, 118.554876573351 37.2987242296007, 118.55459906684 37.2925846354167, 118.550946180556 37.2930788845486, 118.550477701823 37.2840171983507, 118.55042561849 37.2826451280382, 118.549118923611 37.2831212022569, 118.5491796875 37.2845974392361, 118.547673882378 37.286598578559, 118.545052083333 37.2896790907118, 118.545147840712 37.292497016059, 118.543797743056 37.2925480143229, 118.54364203559 37.2912586805556, 118.542266438802 37.2927213541667, 118.541695421007 37.2931873914931, 118.54075249566 37.2937584092882, 118.538183051215 37.2950895182292, 118.523833821615 37.2947596571181, 118.524025065104 37.3037217881944, 118.523013237847 37.3039114040799, 118.518058539497 37.3045817057292, 118.514262695312 37.304970703125, 118.511426595052 37.305439453125, 118.51048421224 37.3055810546875, 118.510319010417 37.2956287977431, 118.50709391276 37.2961596679688, 118.50705078125 37.2961686197917, 118.506506076389 37.2962874348958, 118.480116102431 37.3011672634549, 118.479190538194 37.3013172743056, 118.478801540799 37.3008797200521, 118.478126627604 37.3001131184896, 118.477763400608 37.2991674804688, 118.475116373698 37.299130859375, 118.470289442274 37.298756781684, 118.468662923177 37.299030219184, 118.468602430556 37.2998684353299, 118.470064832899 37.3025352647569, 118.470508897569 37.3036146375868, 118.465323621962 37.3034022352431, 118.462753634983 37.3032082790799, 118.457379286024 37.3036325412326, 118.456989474826 37.3027129448785, 118.452478298611 37.2916357421875, 118.452322319878 37.2912537977431, 118.443385687934 37.2911520724826, 118.442736002604 37.2904234483507, 118.442181803385 37.2907717556424, 118.446496039497 37.3011344401042, 118.446807996962 37.3019460720486, 118.44172390408 37.3006252712674, 118.437149522569 37.2999194335938, 118.431187608507 37.2996264648437, 118.430979546441 37.2991490342882, 118.428985460069 37.2946826171875, 118.42521484375 37.2958148871528, 118.423731825087 37.2929760742187, 118.421451280382 37.2932988823785, 118.421295572917 37.2945060221354, 118.422691786024 37.2976578776042, 118.422821994358 37.2985782877604, 118.418815375434 37.2966438802083, 118.415640733507 37.2946997070312, 118.414755588108 37.2925678168403, 118.413914116753 37.2914434136285, 118.413098415799 37.2897802734375, 118.411588812934 37.289797905816, 118.409662543403 37.2898285590278, 118.409576009115 37.2927205403646, 118.405670572917 37.2893288845486, 118.405348849826 37.2849386935764, 118.405600585938 37.2843004014757, 118.407145182292 37.2843050130208, 118.407049696181 37.2825461154514, 118.402310655382 37.2819243706597, 118.401728244358 37.2769346788194, 118.396927354601 37.2768893771701, 118.397795138889 37.2729337565104, 118.397508409288 37.2720912000868, 118.395936686198 37.2717952473958, 118.391429578993 37.2721180555556, 118.391090766059 37.2712839084201, 118.391593695747 37.2644840494792, 118.390655381944 37.2621253797743, 118.389092068142 37.2617635091146, 118.383210720486 37.2623532443576, 118.376858452691 37.2620030381944, 118.375911187066 37.262001953125, 118.375815429688 37.2596959092882, 118.375763075087 37.2584971788194, 118.368374565972 37.2585782877604, 118.367348632812 37.2560799153646, 118.367061631944 37.2552761501736, 118.364296875 37.2544943576389, 118.360330946181 37.2445781792535, 118.358678656684 37.2437849934896, 118.355217827691 37.243857421875, 118.350443250868 37.243779296875, 118.347520345052 37.2371253797743, 118.346641438802 37.233258734809, 118.346884765625 37.2318391927083, 118.347789171007 37.2313587782118, 118.354998914931 37.2317540147569, 118.35375515408 37.23107421875, 118.349928385417 37.2288568793403, 118.355519476997 37.2202639431424, 118.358067220052 37.2191566297743, 118.360188530816 37.2177010091146, 118.363465983073 37.2124297417535, 118.364195963542 37.2101814778646, 118.36682156033 37.2099986436632, 118.371350640191 37.2087239583333, 118.371915418837 37.2082470703125, 118.371923828125 37.2063709852431, 118.375930718316 37.2061157226562, 118.376730143229 37.2040451388889, 118.37666015625 37.2016132269965, 118.377485894097 37.2016357421875, 118.377572699653 37.2011539713542, 118.376598849826 37.1969661458333, 118.379414605035 37.1963658311632, 118.380083007813 37.1919976128472, 118.381264648437 37.1911303710937, 118.383393554688 37.1905897352431, 118.382680664063 37.1879486762153, 118.382446017795 37.1870277235243, 118.38434000651 37.1861653645833, 118.384096137153 37.1823999023437, 118.387067328559 37.1823548719618, 118.387605794271 37.1810175238715, 118.387562120226 37.1778211805556, 118.383913302951 37.1783390299479, 118.383548177083 37.1751638454861, 118.38046359592 37.1751779513889, 118.380775824653 37.1704836697049, 118.378837890625 37.1700645616319, 118.378515896267 37.1656342230903, 118.377655436198 37.1655552842882, 118.377584906684 37.15568359375, 118.377575954861 37.1541764322917, 118.376941460503 37.1541365559896, 118.371883138021 37.154108344184, 118.371673990885 37.1496956380208, 118.371065538194 37.1494775390625, 118.367979600694 37.1501896158854, 118.36660563151 37.1468001302083, 118.366414388021 37.1468606228299, 118.364153917101 37.1477473958333, 118.36157172309 37.1484860568576, 118.36128499349 37.1481553819444, 118.356788736979 37.1430753580729, 118.356510416667 37.1413766818576, 118.35620578342 37.1393348524306, 118.347622070312 37.1398234049479, 118.346586914062 37.1378800455729, 118.346056043837 37.134313422309, 118.343872884115 37.1342659505208, 118.342150878906 37.1336328125, 118.341037326389 37.1328187391493, 118.34069797092 37.1317279730903, 118.341349826389 37.127946234809, 118.342254231771 37.1260934787326, 118.346020507812 37.1269300672743, 118.346507432726 37.1269745551215, 118.346315917969 37.1245939127604, 118.346081000434 37.1239116753472, 118.345341525608 37.1239016384549, 118.34005343967 37.1237396918403, 118.338244357639 37.1231195746528, 118.34012234158 37.1164694552951, 118.342653537326 37.1188541666667, 118.346506076389 37.1151220703125, 118.346349283854 37.1128285047743, 118.344922688802 37.1114404296875, 118.344896375868 37.110081108941, 118.346488172743 37.1101144748264, 118.34719265408 37.1097203233507, 118.348827582465 37.1083726671007, 118.349566514757 37.1070450846354, 118.349983723958 37.1037841796875, 118.34936577691 37.101754828559, 118.346069607205 37.101887749566, 118.342599555122 37.104208984375, 118.342025553385 37.10388671875, 118.341538085938 37.1010017903646, 118.338528917101 37.1027419704861, 118.338259849805 37.1030906597372, 118.334083518739 37.102983241172, 118.334014756944 37.1017692057292, 118.336824001736 37.1018267144097, 118.337163085938 37.1008110894097, 118.336875813802 37.0985302734375, 118.339058973524 37.0969797092014, 118.338832465278 37.0938826497396, 118.342476671007 37.0938547092014, 118.342989637587 37.0922661675347, 118.342336968316 37.0892854817708, 118.336979166667 37.0888755967882, 118.336648220486 37.0859695095486, 118.334482421875 37.0844973415799, 118.332942437066 37.0819360351562, 118.332628851997 37.0778439670139, 118.334785970052 37.0775528971354, 118.336603190104 37.0733216688368, 118.337455512153 37.0723635525174, 118.338542751736 37.0722612847222, 118.337063530816 37.0670901150174, 118.336114908854 37.0617895507812, 118.33565375434 37.0601597764757, 118.336123046875 37.0574419487847, 118.337523328993 37.0566582573785, 118.33762749566 37.055403374566, 118.337557779948 37.0539005533854, 118.33043375651 37.0500952148438, 118.324562445747 37.046279296875, 118.324214138455 37.0429082573785, 118.325440266927 37.0405390082465, 118.326588270399 37.0402674696181, 118.326744791667 37.0396034071181, 118.325865885417 37.0354408094618, 118.323613009983 37.0326133897569, 118.319081488715 37.0292955186632, 118.3158984375 37.0283775499132, 118.311567925347 37.0286653645833, 118.310150282118 37.0282373046875, 118.308584798177 37.0245993381076, 118.308367241753 37.0215323893229, 118.308201768663 37.0199034288194, 118.306366916233 37.0183846028646, 118.301176757812 37.0186458333333, 118.299490288628 37.0181914605035, 118.298168945312 37.0162828233507, 118.297525227865 37.0130330403646, 118.295995551215 37.0131089952257, 118.295004340278 37.0120697699653, 118.294412977431 37.0089982096354, 118.28998969184 37.0094571940104, 118.289102376302 37.0015600585938, 118.289023980035 37.0007866753472, 118.288968395371 37.0005632053882, 118.2889545 37.00050557, 118.28882405599 36.9999829101562, 118.289718967014 36.9976038953993, 118.291639268663 36.995881890191, 118.292923719618 36.9816417100694, 118.293475748698 36.9776733398437, 118.293462456597 36.9776483832465, 118.29348171658 36.9776304796007, 118.294591200087 36.9696560329861, 118.305448676215 36.96998046875, 118.30872639974 36.9704245334201, 118.312491590712 36.9709044053819, 118.312500542535 36.9722856987847, 118.313917914497 36.972444390191, 118.318040093316 36.9728515625, 118.317996690538 36.9745496961806, 118.322345106337 36.9745054796007, 118.322300889757 36.9671085611979, 118.324727376302 36.9673044162326, 118.32465766059 36.9647675238715, 118.328084309896 36.9635579427083, 118.334259440104 36.9620233832465, 118.340843641493 36.9610891384549, 118.344278971354 36.9607134331597, 118.344870876736 36.9636159939236, 118.350314823636 36.9672313455237, 118.350313873063 36.9674817502144, 118.350865246511 36.9677925634584, 118.351168348524 36.9720711263021, 118.352220865885 36.9726245117187, 118.352299262153 36.9745792643229, 118.361264648437 36.9747856987847, 118.361690809462 36.9747734917535, 118.370836588542 36.9745005967882, 118.372036132812 36.9748887803819, 118.375677897135 36.9749197048611, 118.381639268663 36.9748353407118, 118.384680175781 36.974377983941, 118.384532063802 36.9715676540799, 118.387590060764 36.9712969292535, 118.386981336806 36.9673090277778, 118.387789171007 36.9661325412326, 118.387406684028 36.9634350585938, 118.388787706163 36.9631016710069, 118.386745605469 36.9560158962674, 118.387179904514 36.9553735351562, 118.38850016276 36.9550618489583, 118.389099392361 36.9537421332465, 118.386354672901 36.9512395051342, 118.386527031949 36.9504736783567, 118.390332302517 36.9480748155382, 118.392789984809 36.9475249565972, 118.394622395833 36.9483642578125, 118.396836751302 36.9491126844618, 118.397201605903 36.9492171223958, 118.397548828125 36.9492561848958, 118.39782687717 36.9494517686632, 118.398356391059 36.9495431857639, 118.39860812717 36.9491655815972, 118.401794433594 36.9498095703125, 118.401924099392 36.9456876627604, 118.403234592014 36.9431426323785, 118.407001139323 36.9418446180556, 118.410333387587 36.9418229166667, 118.421158854167 36.9416848415799, 118.422399088542 36.9422922092014, 118.423002105098 36.9438269639495, 118.429518769732 36.9440105910473, 118.434179416233 36.9446964518229, 118.439100477431 36.9422189670139, 118.462945963542 36.9466487630208, 118.462876790365 36.9459106445313, 118.46231391059 36.9424370659722, 118.462452256944 36.9413986545139, 118.465714518229 36.9412608506944, 118.466164279514 36.9412467447917, 118.466347113715 36.9416528320313, 118.466361219618 36.9416918945313, 118.46637749566 36.9417198350694, 118.466571180556 36.9421492513021, 118.467376302083 36.9454961480035, 118.467635904948 36.9465638563368, 118.467835015191 36.9475320095486, 118.470231662326 36.947916937934, 118.47149468316 36.9488997395833, 118.472706163194 36.9507600911458, 118.473735894097 36.9539279513889, 118.474506022135 36.9560327148438, 118.476659884983 36.9570912000868, 118.486666395399 36.9566419813368, 118.489640842014 36.9549525282118, 118.493549262153 36.9547892252604, 118.496696506076 36.9538633897569, 118.497491861979 36.9519194878472, 118.503362630208 36.9515717230903, 118.50376030816 36.9515443250868, 118.503717176649 36.9503588867188, 118.503189019097 36.9442667643229, 118.506457248264 36.9438180881076, 118.507823079427 36.9430018446181, 118.512682562934 36.9429047309028, 118.514947916667 36.943805609809, 118.521355523003 36.9438563368056, 118.52144863828 36.9452496622572, 118.524557255228 36.945278949473, 118.524935709635 36.9447580295139, 118.525359429253 36.9441921657986, 118.525368109809 36.9436363389757, 118.525644802517 36.9430710177951, 118.525800238715 36.9425056966146, 118.526076931424 36.9419447157118, 118.526638997396 36.9413785807292, 118.526872558594 36.9408306206597, 118.526933051215 36.9402571614583, 118.527080078125 36.9396964518229, 118.528948025174 36.9393088107639, 118.530781521267 36.9391343858507, 118.534890136719 36.9373771158854, 118.537753363715 36.9367702907986, 118.544562445747 36.9363492838542, 118.54541937934 36.9373027886285, 118.548534884983 36.9370393880208, 118.549244520399 36.9387882486979, 118.551564618918 36.9387638082809, 118.554642932554 36.9383723494501, 118.554897148659 36.9423072837816, 118.553694118924 36.9423749457465, 118.553901909722 36.9438338216146, 118.554603135851 36.9441710069444, 118.555295681424 36.9445171440972, 118.555711263021 36.9449679904514, 118.555988498264 36.9455276150174, 118.55626546224 36.9460959201389, 118.556404079861 36.9466517469618, 118.557096896701 36.9468893771701, 118.55779812283 36.9467751736111, 118.558499348958 36.9467738172743, 118.5607421875 36.9465608723958, 118.560785590278 36.9490410698785, 118.562197536892 36.9513359917535, 118.562206217448 36.9524392361111, 118.560353461372 36.9556784396701, 118.558361816406 36.9562773980035, 118.558102484809 36.9589057074653, 118.5584542232 36.9617376673028, 118.555995761199 36.9631584991552, 118.555900999097 36.9632785373264, 118.55581841 36.963428, 118.557462565104 36.9653870985243, 118.558406846788 36.9702368164062, 118.558649359809 36.9708881293403, 118.559420301649 36.9747694227431, 118.55974093967 36.9760677083333, 118.559818793403 36.9770578342014, 118.558442382813 36.9795448133681, 118.557446831597 36.9798291015625, 118.554572482639 36.9795654296875, 118.552295735677 36.9796657986111, 118.553049587674 36.9855886501736, 118.553110351562 36.9867613389757, 118.551725531684 36.9878762478299, 118.552747667101 36.9943717447917, 118.553007541233 36.9965687391493, 118.55399468316 37.0002454969618, 118.554869249132 37.0005476888021, 118.55705078125 37.0005780707465, 118.557570258247 37.0005989583333, 118.55983859592 36.998987358941, 118.560098198785 36.9961376953125, 118.564133300781 36.9941802300347, 118.566697048611 36.9940893554688, 118.567121582031 36.9940104166667, 118.56752875434 36.9946134440104, 118.575023057726 36.9939469401042, 118.57481499566 36.992249077691, 118.576011013455 36.9921780056424, 118.576695963542 36.9958387586806, 118.578533257378 36.9957063802083, 118.579304741753 36.9951190863715, 118.580466308594 36.9950179036458, 118.581185980903 36.996494140625, 118.57940890842 36.9974948459201, 118.579383138021 36.9983764648438, 118.574460449219 36.9989729817708, 118.573524305556 36.9965201822917, 118.571540256076 36.9971440972222, 118.570760633681 36.9979747178819, 118.568100857205 36.9985302734375, 118.566212565104 36.9990326605903, 118.566134982639 37.0006008572049, 118.56611843533 37.0010061306424, 118.566169704861 37.0013593207465, 118.566187879774 37.0014360894097, 118.566230197483 37.0021034071181, 118.567555609809 37.0024663628472, 118.56757297092 37.0033913845486, 118.567564832899 37.0064013671875, 118.571159939236 37.0061526150174, 118.571012369792 37.0042765299479, 118.571185709635 37.0041286892361, 118.579192979601 37.0037060546875, 118.57921875 37.0023901367188, 118.584489746094 37.002063530816, 118.587507324219 37.0017963324653, 118.589874945747 37.001243218316, 118.59023030599 37.0013517252604, 118.590681694878 37.0035622829861, 118.590629611545 37.0036187065972, 118.590560167101 37.0036317274306, 118.589805772569 37.0041012912326, 118.588860405816 37.0043798828125, 118.585912000868 37.0049726019965, 118.58651936849 37.0079820421007, 118.58354546441 37.0084274631076, 118.583623318142 37.0088053385417, 118.584568413628 37.0093212890625, 118.584976128472 37.0097683376736, 118.585149739583 37.0109497070313, 118.585115017361 37.0118356662326, 118.586285536024 37.0118174913194, 118.586372612847 37.0148011610243, 118.584907226563 37.0149197048611, 118.585627170139 37.0161829969618, 118.588055284288 37.0158165147569, 118.588419596354 37.0174058702257, 118.585904676649 37.0177593315972, 118.585228407118 37.018020562066, 118.583910590278 37.018251953125, 118.581734483507 37.018401421441, 118.576767849392 37.0182373046875, 118.57668999566 37.0200702582465, 118.571906738281 37.0200808376736, 118.571456163194 37.0221012369792, 118.570061577691 37.0223244900174, 118.565998806424 37.0224742296007, 118.565912000868 37.0228784179687, 118.564162597656 37.0230550130208, 118.563270399306 37.0229782443576, 118.562586263021 37.0226451280382, 118.562092556424 37.0221856011285, 118.56142578125 37.0221823459201, 118.561400010851 37.0234724934896, 118.557425672743 37.0235148111979, 118.556282823351 37.0237646484375, 118.545827094184 37.023522406684, 118.546086697049 37.0252289496528, 118.544572482639 37.0251109483507, 118.545524631076 37.0290174696181, 118.545689290365 37.0293646918403, 118.546182725694 37.0310443793403, 118.547013617622 37.0340565321181, 118.545698242187 37.0342898220486, 118.546209038628 37.0363343641493, 118.545084364149 37.0365543619792, 118.545430501302 37.0385080295139, 118.547550726997 37.0384160698785, 118.549013400608 37.0387516276042, 118.550173068576 37.0389314778646, 118.552267795139 37.0386271158854, 118.55263156467 37.0413929578993, 118.558232693142 37.0407126193576, 118.557964138455 37.0396055772569, 118.55857014974 37.0392917209201, 118.559106987847 37.0388953993056, 118.560431857639 37.0387453884549, 118.560120442708 37.0411173502604, 118.560068359375 37.0414214409722, 118.56064860026 37.0420719401042, 118.561350368924 37.0448546006944, 118.561462944878 37.0454668511285, 118.559783257378 37.0458175998264, 118.560562879774 37.0487174479167, 118.560276963976 37.0487657335069, 118.558744574653 37.0489076063368, 118.559065212674 37.0514217122396, 118.557567274306 37.0514507378472, 118.557593315972 37.0515852864583, 118.55775797526 37.0533091905382, 118.557602267795 37.0538001844618, 118.557740885417 37.0560411241319, 118.557766927083 37.0569444444444, 118.558416341146 37.0569086371528, 118.559975043403 37.0568535698785, 118.56131781684 37.0633094618056, 118.56460015191 37.0639637586806, 118.567753092448 37.0645841471354, 118.567718370226 37.0644235568576, 118.567614474826 37.0633509657118, 118.570403917101 37.0630034722222, 118.570733235677 37.0642670355903, 118.572821180556 37.0643855794271, 118.573999565972 37.0638758680556, 118.575264756944 37.0636876085069, 118.580413140191 37.0633083767361, 118.580751681858 37.0666956922743, 118.583100857205 37.0669235568576, 118.585806206597 37.0673426649306, 118.587384440104 37.0676500108507, 118.591443413628 37.0684554036458, 118.592302246094 37.0683289930556, 118.597533637153 37.0676147460938, 118.598826226128 37.0650735134549, 118.600665961372 37.0650168185764, 118.601681315104 37.0649169921875, 118.601464301215 37.0633577473958, 118.603981119792 37.0632359483507, 118.604259168837 37.0639569769965, 118.607497016059 37.0636751302083, 118.607462293837 37.0634144422743, 118.61091796875 37.0630246310764, 118.610683322483 37.0618302408854, 118.615129665799 37.0626093207465, 118.615460069444 37.0637215169271, 118.631882324219 37.0667407226562, 118.632152235243 37.0704242621528, 118.636281467014 37.0703944227431, 118.638202853733 37.0703578016493, 118.641967773438 37.0700547960069, 118.640811360677 37.0725070529514, 118.643976779514 37.0729546440972, 118.647438151042 37.0737632921007, 118.648681911892 37.0740215386285, 118.648568793403 37.0748334418403, 118.648290744358 37.076005859375, 118.648282063802 37.0769222005208, 118.648290744358 37.0770524088542, 118.654109700521 37.0769490559896, 118.655485297309 37.0826763237847, 118.665167914497 37.0817599826389, 118.665403103299 37.0826812065972, 118.666029730903 37.0851841905382, 118.666377766927 37.0862532552083, 118.668100857205 37.0878721788194, 118.668718532986 37.0885118272569, 118.666647949219 37.0887510850694, 118.667004665799 37.0901025390625, 118.668222927517 37.0903436957465, 118.668388400608 37.0915383572049, 118.663986002604 37.0923160807292, 118.663977322049 37.0924812825521, 118.663464626736 37.0983089192708, 118.663638509115 37.0985218641493, 118.663899739583 37.0986962890625, 118.664134657118 37.098713921441, 118.663865288628 37.1020534939236, 118.668171929253 37.1015445963542, 118.668502604167 37.1015147569444, 118.668432888455 37.1020792643229, 118.667372233073 37.1092130533854, 118.666946343316 37.1121918402778, 118.667077094184 37.1139076063368, 118.667372775608 37.1141121419271, 118.670087619358 37.114951171875, 118.670600857205 37.1151692708333, 118.670670572917 37.1152650282118, 118.670914171007 37.115791015625, 118.670983886719 37.1160560438368, 118.671453721788 37.1167735460069, 118.671645236545 37.116943359375, 118.670966525608 37.1171199544271, 118.671784667969 37.1186027018229, 118.673907877604 37.1216295030382, 118.669105360243 37.1230059136285, 118.669662543403 37.1261512586806, 118.670750868056 37.1325984700521, 118.671969672309 37.1400577799479, 118.672143825955 37.1405447048611, 118.673414442274 37.1430834960938, 118.673719075521 37.1443218315972, 118.667672254774 37.1461735026042, 118.666497395833 37.1438693576389, 118.657902289497 37.1474237738715, 118.653613823785 37.1496877712674, 118.653143988715 37.1495393880208, 118.651725802951 37.1458018663194, 118.650055881076 37.1463376193576, 118.650569118924 37.1471115451389, 118.651891818576 37.1518996853299, 118.652683648003 37.1552408854167, 118.652936197917 37.1579470486111, 118.650511322215 37.1587161096567, 118.651367358233 37.1616036827537, 118.651171198349 37.1618313272211, 118.650188259549 37.1634450954861, 118.649727376302 37.1638742404514, 118.649196777344 37.16423828125, 118.648779296875 37.1642721896701, 118.64833577474 37.1639979383681, 118.647639702691 37.1622119140625, 118.646596137153 37.1624533420139, 118.645684994555 37.1595673925375, 118.63622398824 37.1615003559942, 118.636648763021 37.1630300564236, 118.634153645833 37.1633569335937, 118.63478000217 37.1658157009549, 118.634223632813 37.1671918402778, 118.634171549479 37.1677129448785, 118.633633083767 37.1711824544271, 118.636866861979 37.1711124674479, 118.638701443142 37.1711279296875, 118.639640842014 37.1749074978299, 118.643049587674 37.1749688042535, 118.643919542101 37.1783534071181, 118.645467393663 37.1781515842014, 118.647807617187 37.1854641384549, 118.648346896701 37.1853868272569, 118.649295247396 37.1891102430556, 118.649808485243 37.189045952691, 118.650147569444 37.1890812174479, 118.650339084201 37.1891946072049, 118.650495605469 37.1895334201389, 118.650921766493 37.1896036783854, 118.652739066946 37.1886993785832, 118.654574924045 37.1874861653646, 118.654383680556 37.1886973741319, 118.654644639757 37.1901483832465, 118.660386013455 37.1878957790799, 118.660769042969 37.1899899631076, 118.660839029948 37.1929953342014, 118.662552897135 37.1929418945313, 118.663431803385 37.1947805447049, 118.665032552083 37.194401312934, 118.665424262153 37.1965649414063, 118.667129720052 37.1966026475694, 118.667138400608 37.1971457248264, 118.667355957031 37.1975412326389, 118.667930230035 37.1980069986979, 118.668260904948 37.1980900065104, 118.66853922526 37.1982253689236, 118.668791503906 37.198447265625, 118.668843858507 37.1987513563368, 118.668826497396 37.1989987521701, 118.668730740017 37.199137641059, 118.668522135417 37.1993977864583, 118.668087022569 37.1995402018229, 118.66750406901 37.1997129991319, 118.666947157118 37.2001331922743, 118.666842990451 37.2003415256076, 118.666877712674 37.2005194769965, 118.667121310764 37.2008848741319, 118.667521701389 37.2012546115451, 118.668992241753 37.2023388671875, 118.669818793403 37.2030265299479, 118.670053710937 37.203196343316, 118.67036702474 37.2031882052951, 118.6712109375 37.2026904296875, 118.67156765408 37.2027039930556, 118.671915690104 37.2028393554687, 118.672568359375 37.2029361979167, 118.673327907986 37.2030872938368, 118.673031141493 37.2038186306424, 118.672297905816 37.2036781141493, 118.671878526476 37.2043047417535, 118.67166937934 37.2049319118924, 118.671931152344 37.2056296115451, 118.672018500434 37.2064143880208, 118.671948784722 37.2076345486111, 118.67200141059 37.2083319769965, 118.672455512153 37.208977593316, 118.672647569444 37.209710015191, 118.672490505642 37.2105466037326, 118.672159016927 37.2113826497396, 118.672316080729 37.212219780816, 118.672817382812 37.2127218967014, 118.672845323351 37.2133772786458, 118.672119140625 37.2142545572917, 118.67210530599 37.2147148980035, 118.672343478733 37.2151478407118, 118.673320855035 37.2162651909722, 118.673977593316 37.2170613606771, 118.674592285156 37.2184847005208, 118.675031195747 37.2189401584201, 118.675793999566 37.2192960611979, 118.67696234809 37.2196964518229, 118.677660861545 37.2201999240451, 118.678177897135 37.2210234917535, 118.678457573785 37.221875, 118.678513454861 37.2228648546007, 118.678331705729 37.2237711588542, 118.678052571615 37.2242727322049, 118.677577853733 37.2247374131944, 118.676701931424 37.2254766167535, 118.676147460938 37.2261447482639, 118.675494791667 37.2269203016493, 118.675146213108 37.2275531684028, 118.67498453776 37.2280523003472, 118.674772677951 37.2288102213542, 118.677125651042 37.2289181857639, 118.680630425347 37.2292857530382, 118.68279812283 37.2300832790799, 118.685833062066 37.2320364040799, 118.688831651476 37.2334483506944, 118.692505696615 37.2349888780382, 118.700428331163 37.2377967664931, 118.704120008681 37.238952094184, 118.707051323785 37.2401380750868, 118.709710557726 37.2412741427951, 118.711365559896 37.2424943033854, 118.71326171875 37.2447810872396, 118.714296603733 37.245651312934, 118.721662597656 37.2496210394965, 118.728425021701 37.2527642144097, 118.735143229167 37.2565700954861, 118.736472710503 37.2571834309896, 118.743666178385 37.261373969184, 118.754669325087 37.2674869791667, 118.759548068576 37.2702964952257, 118.766161295573 37.2736645507812, 118.766655815972 37.2739206271701, 118.771245659722 37.2767540147569, 118.777976888021 37.2801106770833, 118.779711371528 37.2804695638021, 118.782858886719 37.2806361219618, 118.78701171875 37.2802281358507, 118.786977267795 37.2812269422743, 118.806953667535 37.2858113606771, 118.821896701389 37.2887687174479, 118.840726182726 37.2914561631944, 118.845316840278 37.2921034071181, 118.856959092882 37.2938503689236, 119.039890136719 37.3044664171007))";
//        System.out.println(GeometryUtils.getAreaByWkt(wkt));

        //String wkt = "POLYGON((119.039890136719 37.3044664171007, 119.035866427951 37.3061189778646, 119.030822753906 37.3081287977431, 119.02196234809 37.3102964952257, 119.010303548177 37.3132101779514, 119.001206325955 37.3187581380208, 118.993556043837 37.3273980034722, 118.986952853733 37.3395109049479, 118.98312906901 37.350016547309, 118.981622721354 37.358792046441, 118.981431206597 37.3598250325521, 118.963889702691 37.3569094509549, 118.958857421875 37.3558213975694, 118.950144856771 37.3536802842882, 118.944419759115 37.35193359375, 118.940392252604 37.3509676106771, 118.936956922743 37.3501508246528, 118.932513834635 37.3500716145833, 118.928871527778 37.3502501085069, 118.926707085503 37.3505520290799, 118.922336425781 37.3517125108507, 118.916750488281 37.3539499240451, 118.914483506944 37.3551255967882, 118.908639865451 37.3574085828993, 118.906834038628 37.3583506944444, 118.905965983073 37.3591799587674, 118.904837510851 37.358359375, 118.903457302517 37.3571698676215, 118.903005642361 37.3563709852431, 118.902918836806 37.3555590820312, 118.90298828125 37.3540828450521, 118.902658148872 37.3513690863715, 118.902484266493 37.3497970920139, 118.901789822049 37.3483732096354, 118.900314127604 37.345625, 118.89896891276 37.3443617078993, 118.897406955295 37.3432638888889, 118.895307074653 37.3423182508681, 118.89095187717 37.3406968858507, 118.888636067708 37.3398689778646, 118.887005208333 37.3388671875, 118.885860460069 37.3376871744792, 118.884594184028 37.335530327691, 118.882330457899 37.3315983072917, 118.881324598524 37.3301185438368, 118.880119357639 37.3290896267361, 118.879157172309 37.3287369791667, 118.878136664497 37.3287182617187, 118.877050238715 37.3288772243924, 118.875862901476 37.3294300672743, 118.873635253906 37.3307180447049, 118.871199815538 37.3315766059028, 118.869665798611 37.3317523871528, 118.866708170573 37.331530219184, 118.864697265625 37.3312136501736, 118.862508138021 37.3308596462674, 118.860879177517 37.3308884006076, 118.859770236545 37.3309073893229, 118.857517632378 37.3312543402778, 118.855888943142 37.3315825737847, 118.851965060764 37.332848578559, 118.85049235026 37.3332071940104, 118.850163302951 37.3332381184896, 118.835256890191 37.3326969401042, 118.831861979167 37.3325729709201, 118.825799153646 37.3325105794271, 118.821823730469 37.3322789171007, 118.819129774306 37.3314718967014, 118.818324110243 37.331243218316, 118.816892903646 37.3305124240451, 118.814613172743 37.3298285590278, 118.812798936632 37.3295857747396, 118.807331000434 37.3297667100694, 118.803064507378 37.329625922309, 118.798454047309 37.3290182834201, 118.794315863715 37.3284282769097, 118.791940917969 37.3281966145833, 118.788820529514 37.3284654405382, 118.784624565972 37.3289474826389, 118.781277669271 37.3295195855035, 118.777600911458 37.3298787434896, 118.773350965712 37.3298426649306, 118.768753255208 37.3294458007813, 118.763122558594 37.3288636610243, 118.759388834635 37.3283333333333, 118.757423502604 37.3280780707465, 118.75485921224 37.3278209092882, 118.75100124783 37.3278206380208, 118.748912489149 37.3277954101562, 118.747609592014 37.327451171875, 118.746060926649 37.3267130533854, 118.742864854601 37.3243519422743, 118.740652126736 37.3233430989583, 118.738021375868 37.3229728190104, 118.734480251736 37.3226996527778, 118.730298936632 37.3223027886285, 118.728478732639 37.3220798068576, 118.725199652778 37.326569281684, 118.721975097656 37.3301087782118, 118.720949164497 37.3316663953993, 118.719454210069 37.3341178385417, 118.71743733724 37.3370505099826, 118.701199544271 37.3372254774306, 118.701190863715 37.3380938042535, 118.696876085069 37.3381079101563, 118.696101616753 37.3381065538194, 118.697014973958 37.3370705837674, 118.695701497396 37.3371158854167, 118.695657823351 37.3363427734375, 118.687409667969 37.3364927842882, 118.684921332465 37.3365793185764, 118.684851616753 37.3352547200521, 118.676637641059 37.3353214518229, 118.681292317708 37.3295640733507, 118.677707248264 37.3294398328993, 118.677681206597 37.3305471462674, 118.678953450521 37.330612250434, 118.67879828559 37.3322688802083, 118.67656765408 37.3322992621528, 118.676524251302 37.3311181640625, 118.672434624566 37.3311146375868, 118.672356228299 37.3293123372396, 118.676880696615 37.3295079210069, 118.679577636719 37.3255007595486, 118.666891547309 37.3253550889757, 118.663420681424 37.3303854709201, 118.66208062066 37.3294930013021, 118.661393500434 37.3291965060764, 118.659601508247 37.3312253146701, 118.639752604167 37.3213538953993, 118.638065321181 37.3168052842882, 118.636952039931 37.3118145073785, 118.635552300347 37.3113351779514, 118.63469156901 37.3113384331597, 118.630736490885 37.3113425021701, 118.623106282552 37.3112961154514, 118.620291341146 37.3112331814236, 118.602689615885 37.3112906901042, 118.602368977865 37.3144487847222, 118.599557020399 37.3147531467014, 118.59567843967 37.3154009331597, 118.595486653646 37.3057524956597, 118.585061306424 37.3056236436632, 118.585200737847 37.3140044487847, 118.58373562283 37.3139925130208, 118.583751898872 37.3056073676215, 118.580188802083 37.3055631510417, 118.579460720486 37.3055419921875, 118.579635687934 37.3192941623264, 118.57156765408 37.3211797417535, 118.566794433594 37.3221508789062, 118.566871744792 37.3155767144097, 118.562047526042 37.3157194010417, 118.562073567708 37.314342719184, 118.562176649306 37.3079418945312, 118.562193739149 37.3057405598958, 118.562202419705 37.3050716145833, 118.555084364149 37.2990842013889, 118.554452582465 37.2990161132812, 118.554574652778 37.3081868489583, 118.554739583333 37.3116691080729, 118.553908420139 37.3118573676215, 118.551190592448 37.3124452039931, 118.550289171007 37.2993636067708, 118.552530653212 37.298994140625, 118.553586697049 37.2988354492187, 118.553915744358 37.2988389756944, 118.554755588108 37.2989154730903, 118.554876573351 37.2987242296007, 118.55459906684 37.2925846354167, 118.550946180556 37.2930788845486, 118.550477701823 37.2840171983507, 118.55042561849 37.2826451280382, 118.549118923611 37.2831212022569, 118.5491796875 37.2845974392361, 118.547673882378 37.286598578559, 118.545052083333 37.2896790907118, 118.545147840712 37.292497016059, 118.543797743056 37.2925480143229, 118.54364203559 37.2912586805556, 118.542266438802 37.2927213541667, 118.541695421007 37.2931873914931, 118.54075249566 37.2937584092882, 118.538183051215 37.2950895182292, 118.523833821615 37.2947596571181, 118.524025065104 37.3037217881944, 118.523013237847 37.3039114040799, 118.518058539497 37.3045817057292, 118.514262695312 37.304970703125, 118.511426595052 37.305439453125, 118.51048421224 37.3055810546875, 118.510319010417 37.2956287977431, 118.50709391276 37.2961596679688, 118.50705078125 37.2961686197917, 118.506506076389 37.2962874348958, 118.480116102431 37.3011672634549, 118.479190538194 37.3013172743056, 118.478801540799 37.3008797200521, 118.478126627604 37.3001131184896, 118.477763400608 37.2991674804688, 118.475116373698 37.299130859375, 118.470289442274 37.298756781684, 118.468662923177 37.299030219184, 118.468602430556 37.2998684353299, 118.470064832899 37.3025352647569, 118.470508897569 37.3036146375868, 118.465323621962 37.3034022352431, 118.462753634983 37.3032082790799, 118.457379286024 37.3036325412326, 118.456989474826 37.3027129448785, 118.452478298611 37.2916357421875, 118.452322319878 37.2912537977431, 118.443385687934 37.2911520724826, 118.442736002604 37.2904234483507, 118.442181803385 37.2907717556424, 118.446496039497 37.3011344401042, 118.446807996962 37.3019460720486, 118.44172390408 37.3006252712674, 118.437149522569 37.2999194335938, 118.431187608507 37.2996264648437, 118.430979546441 37.2991490342882, 118.428985460069 37.2946826171875, 118.42521484375 37.2958148871528, 118.423731825087 37.2929760742187, 118.421451280382 37.2932988823785, 118.421295572917 37.2945060221354, 118.422691786024 37.2976578776042, 118.422821994358 37.2985782877604, 118.418815375434 37.2966438802083, 118.415640733507 37.2946997070312, 118.414755588108 37.2925678168403, 118.413914116753 37.2914434136285, 118.413098415799 37.2897802734375, 118.411588812934 37.289797905816, 118.409662543403 37.2898285590278, 118.409576009115 37.2927205403646, 118.405670572917 37.2893288845486, 118.405348849826 37.2849386935764, 118.405600585938 37.2843004014757, 118.407145182292 37.2843050130208, 118.407049696181 37.2825461154514, 118.402310655382 37.2819243706597, 118.401728244358 37.2769346788194, 118.396927354601 37.2768893771701, 118.397795138889 37.2729337565104, 118.397508409288 37.2720912000868, 118.395936686198 37.2717952473958, 118.391429578993 37.2721180555556, 118.391090766059 37.2712839084201, 118.391593695747 37.2644840494792, 118.390655381944 37.2621253797743, 118.389092068142 37.2617635091146, 118.383210720486 37.2623532443576, 118.376858452691 37.2620030381944, 118.375911187066 37.262001953125, 118.375815429688 37.2596959092882, 118.375763075087 37.2584971788194, 118.368374565972 37.2585782877604, 118.367348632812 37.2560799153646, 118.367061631944 37.2552761501736, 118.364296875 37.2544943576389, 118.360330946181 37.2445781792535, 118.358678656684 37.2437849934896, 118.355217827691 37.243857421875, 118.350443250868 37.243779296875, 118.347520345052 37.2371253797743, 118.346641438802 37.233258734809, 118.346884765625 37.2318391927083, 118.347789171007 37.2313587782118, 118.354998914931 37.2317540147569, 118.35375515408 37.23107421875, 118.349928385417 37.2288568793403, 118.355519476997 37.2202639431424, 118.358067220052 37.2191566297743, 118.360188530816 37.2177010091146, 118.363465983073 37.2124297417535, 118.364195963542 37.2101814778646, 118.36682156033 37.2099986436632, 118.371350640191 37.2087239583333, 118.371915418837 37.2082470703125, 118.371923828125 37.2063709852431, 118.375930718316 37.2061157226562, 118.376730143229 37.2040451388889, 118.37666015625 37.2016132269965, 118.377485894097 37.2016357421875, 118.377572699653 37.2011539713542, 118.376598849826 37.1969661458333, 118.379414605035 37.1963658311632, 118.380083007813 37.1919976128472, 118.381264648437 37.1911303710937, 118.383393554688 37.1905897352431, 118.382680664063 37.1879486762153, 118.382446017795 37.1870277235243, 118.38434000651 37.1861653645833, 118.384096137153 37.1823999023437, 118.387067328559 37.1823548719618, 118.387605794271 37.1810175238715, 118.387562120226 37.1778211805556, 118.383913302951 37.1783390299479, 118.383548177083 37.1751638454861, 118.38046359592 37.1751779513889, 118.380775824653 37.1704836697049, 118.378837890625 37.1700645616319, 118.378515896267 37.1656342230903, 118.377655436198 37.1655552842882, 118.377584906684 37.15568359375, 118.377575954861 37.1541764322917, 118.376941460503 37.1541365559896, 118.371883138021 37.154108344184, 118.371673990885 37.1496956380208, 118.371065538194 37.1494775390625, 118.367979600694 37.1501896158854, 118.36660563151 37.1468001302083, 118.366414388021 37.1468606228299, 118.364153917101 37.1477473958333, 118.36157172309 37.1484860568576, 118.36128499349 37.1481553819444, 118.356788736979 37.1430753580729, 118.356510416667 37.1413766818576, 118.35620578342 37.1393348524306, 118.347622070312 37.1398234049479, 118.346586914062 37.1378800455729, 118.346056043837 37.134313422309, 118.343872884115 37.1342659505208, 118.342150878906 37.1336328125, 118.341037326389 37.1328187391493, 118.34069797092 37.1317279730903, 118.341349826389 37.127946234809, 118.342254231771 37.1260934787326, 118.346020507812 37.1269300672743, 118.346507432726 37.1269745551215, 118.346315917969 37.1245939127604, 118.346081000434 37.1239116753472, 118.345341525608 37.1239016384549, 118.34005343967 37.1237396918403, 118.338244357639 37.1231195746528, 118.34012234158 37.1164694552951, 118.342653537326 37.1188541666667, 118.346506076389 37.1151220703125, 118.346349283854 37.1128285047743, 118.344922688802 37.1114404296875, 118.344896375868 37.110081108941, 118.346488172743 37.1101144748264, 118.34719265408 37.1097203233507, 118.348827582465 37.1083726671007, 118.349566514757 37.1070450846354, 118.349983723958 37.1037841796875, 118.34936577691 37.101754828559, 118.346069607205 37.101887749566, 118.342599555122 37.104208984375, 118.342025553385 37.10388671875, 118.341538085938 37.1010017903646, 118.338528917101 37.1027419704861, 118.338259849805 37.1030906597372, 118.334083518739 37.102983241172, 118.334014756944 37.1017692057292, 118.336824001736 37.1018267144097, 118.337163085938 37.1008110894097, 118.336875813802 37.0985302734375, 118.339058973524 37.0969797092014, 118.338832465278 37.0938826497396, 118.342476671007 37.0938547092014, 118.342989637587 37.0922661675347, 118.342336968316 37.0892854817708, 118.336979166667 37.0888755967882, 118.336648220486 37.0859695095486, 118.334482421875 37.0844973415799, 118.332942437066 37.0819360351562, 118.332628851997 37.0778439670139, 118.334785970052 37.0775528971354, 118.336603190104 37.0733216688368, 118.337455512153 37.0723635525174, 118.338542751736 37.0722612847222, 118.337063530816 37.0670901150174, 118.336114908854 37.0617895507812, 118.33565375434 37.0601597764757, 118.336123046875 37.0574419487847, 118.337523328993 37.0566582573785, 118.33762749566 37.055403374566, 118.337557779948 37.0539005533854, 118.33043375651 37.0500952148438, 118.324562445747 37.046279296875, 118.324214138455 37.0429082573785, 118.325440266927 37.0405390082465, 118.326588270399 37.0402674696181, 118.326744791667 37.0396034071181, 118.325865885417 37.0354408094618, 118.323613009983 37.0326133897569, 118.319081488715 37.0292955186632, 118.3158984375 37.0283775499132, 118.311567925347 37.0286653645833, 118.310150282118 37.0282373046875, 118.308584798177 37.0245993381076, 118.308367241753 37.0215323893229, 118.308201768663 37.0199034288194, 118.306366916233 37.0183846028646, 118.301176757812 37.0186458333333, 118.299490288628 37.0181914605035, 118.298168945312 37.0162828233507, 118.297525227865 37.0130330403646, 118.295995551215 37.0131089952257, 118.295004340278 37.0120697699653, 118.294412977431 37.0089982096354, 118.28998969184 37.0094571940104, 118.289102376302 37.0015600585938, 118.289023980035 37.0007866753472, 118.288968395371 37.0005632053882, 118.2889545 37.00050557, 118.28882405599 36.9999829101562, 118.289718967014 36.9976038953993, 118.291639268663 36.995881890191, 118.292923719618 36.9816417100694, 118.293475748698 36.9776733398437, 118.293462456597 36.9776483832465, 118.29348171658 36.9776304796007, 118.294591200087 36.9696560329861, 118.305448676215 36.96998046875, 118.30872639974 36.9704245334201, 118.312491590712 36.9709044053819, 118.312500542535 36.9722856987847, 118.313917914497 36.972444390191, 118.318040093316 36.9728515625, 118.317996690538 36.9745496961806, 118.322345106337 36.9745054796007, 118.322300889757 36.9671085611979, 118.324727376302 36.9673044162326, 118.32465766059 36.9647675238715, 118.328084309896 36.9635579427083, 118.334259440104 36.9620233832465, 118.340843641493 36.9610891384549, 118.344278971354 36.9607134331597, 118.344870876736 36.9636159939236, 118.350314823636 36.9672313455237, 118.350313873063 36.9674817502144, 118.350865246511 36.9677925634584, 118.351168348524 36.9720711263021, 118.352220865885 36.9726245117187, 118.352299262153 36.9745792643229, 118.361264648437 36.9747856987847, 118.361690809462 36.9747734917535, 118.370836588542 36.9745005967882, 118.372036132812 36.9748887803819, 118.375677897135 36.9749197048611, 118.381639268663 36.9748353407118, 118.384680175781 36.974377983941, 118.384532063802 36.9715676540799, 118.387590060764 36.9712969292535, 118.386981336806 36.9673090277778, 118.387789171007 36.9661325412326, 118.387406684028 36.9634350585938, 118.388787706163 36.9631016710069, 118.386745605469 36.9560158962674, 118.387179904514 36.9553735351562, 118.38850016276 36.9550618489583, 118.389099392361 36.9537421332465, 118.386354672901 36.9512395051342, 118.386527031949 36.9504736783567, 118.390332302517 36.9480748155382, 118.392789984809 36.9475249565972, 118.394622395833 36.9483642578125, 118.396836751302 36.9491126844618, 118.397201605903 36.9492171223958, 118.397548828125 36.9492561848958, 118.39782687717 36.9494517686632, 118.398356391059 36.9495431857639, 118.39860812717 36.9491655815972, 118.401794433594 36.9498095703125, 118.401924099392 36.9456876627604, 118.403234592014 36.9431426323785, 118.407001139323 36.9418446180556, 118.410333387587 36.9418229166667, 118.421158854167 36.9416848415799, 118.422399088542 36.9422922092014, 118.423002105098 36.9438269639495, 118.429518769732 36.9440105910473, 118.434179416233 36.9446964518229, 118.439100477431 36.9422189670139, 118.462945963542 36.9466487630208, 118.462876790365 36.9459106445313, 118.46231391059 36.9424370659722, 118.462452256944 36.9413986545139, 118.465714518229 36.9412608506944, 118.466164279514 36.9412467447917, 118.466347113715 36.9416528320313, 118.466361219618 36.9416918945313, 118.46637749566 36.9417198350694, 118.466571180556 36.9421492513021, 118.467376302083 36.9454961480035, 118.467635904948 36.9465638563368, 118.467835015191 36.9475320095486, 118.470231662326 36.947916937934, 118.47149468316 36.9488997395833, 118.472706163194 36.9507600911458, 118.473735894097 36.9539279513889, 118.474506022135 36.9560327148438, 118.476659884983 36.9570912000868, 118.486666395399 36.9566419813368, 118.489640842014 36.9549525282118, 118.493549262153 36.9547892252604, 118.496696506076 36.9538633897569, 118.497491861979 36.9519194878472, 118.503362630208 36.9515717230903, 118.50376030816 36.9515443250868, 118.503717176649 36.9503588867188, 118.503189019097 36.9442667643229, 118.506457248264 36.9438180881076, 118.507823079427 36.9430018446181, 118.512682562934 36.9429047309028, 118.514947916667 36.943805609809, 118.521355523003 36.9438563368056, 118.52144863828 36.9452496622572, 118.524557255228 36.945278949473, 118.524935709635 36.9447580295139, 118.525359429253 36.9441921657986, 118.525368109809 36.9436363389757, 118.525644802517 36.9430710177951, 118.525800238715 36.9425056966146, 118.526076931424 36.9419447157118, 118.526638997396 36.9413785807292, 118.526872558594 36.9408306206597, 118.526933051215 36.9402571614583, 118.527080078125 36.9396964518229, 118.528948025174 36.9393088107639, 118.530781521267 36.9391343858507, 118.534890136719 36.9373771158854, 118.537753363715 36.9367702907986, 118.544562445747 36.9363492838542, 118.54541937934 36.9373027886285, 118.548534884983 36.9370393880208, 118.549244520399 36.9387882486979, 118.551564618918 36.9387638082809, 118.554642932554 36.9383723494501, 118.554897148659 36.9423072837816, 118.553694118924 36.9423749457465, 118.553901909722 36.9438338216146, 118.554603135851 36.9441710069444, 118.555295681424 36.9445171440972, 118.555711263021 36.9449679904514, 118.555988498264 36.9455276150174, 118.55626546224 36.9460959201389, 118.556404079861 36.9466517469618, 118.557096896701 36.9468893771701, 118.55779812283 36.9467751736111, 118.558499348958 36.9467738172743, 118.5607421875 36.9465608723958, 118.560785590278 36.9490410698785, 118.562197536892 36.9513359917535, 118.562206217448 36.9524392361111, 118.560353461372 36.9556784396701, 118.558361816406 36.9562773980035, 118.558102484809 36.9589057074653, 118.5584542232 36.9617376673028, 118.555995761199 36.9631584991552, 118.555900999097 36.9632785373264, 118.55581841 36.963428, 118.557462565104 36.9653870985243, 118.558406846788 36.9702368164062, 118.558649359809 36.9708881293403, 118.559420301649 36.9747694227431, 118.55974093967 36.9760677083333, 118.559818793403 36.9770578342014, 118.558442382813 36.9795448133681, 118.557446831597 36.9798291015625, 118.554572482639 36.9795654296875, 118.552295735677 36.9796657986111, 118.553049587674 36.9855886501736, 118.553110351562 36.9867613389757, 118.551725531684 36.9878762478299, 118.552747667101 36.9943717447917, 118.553007541233 36.9965687391493, 118.55399468316 37.0002454969618, 118.554869249132 37.0005476888021, 118.55705078125 37.0005780707465, 118.557570258247 37.0005989583333, 118.55983859592 36.998987358941, 118.560098198785 36.9961376953125, 118.564133300781 36.9941802300347, 118.566697048611 36.9940893554688, 118.567121582031 36.9940104166667, 118.56752875434 36.9946134440104, 118.575023057726 36.9939469401042, 118.57481499566 36.992249077691, 118.576011013455 36.9921780056424, 118.576695963542 36.9958387586806, 118.578533257378 36.9957063802083, 118.579304741753 36.9951190863715, 118.580466308594 36.9950179036458, 118.581185980903 36.996494140625, 118.57940890842 36.9974948459201, 118.579383138021 36.9983764648438, 118.574460449219 36.9989729817708, 118.573524305556 36.9965201822917, 118.571540256076 36.9971440972222, 118.570760633681 36.9979747178819, 118.568100857205 36.9985302734375, 118.566212565104 36.9990326605903, 118.566134982639 37.0006008572049, 118.56611843533 37.0010061306424, 118.566169704861 37.0013593207465, 118.566187879774 37.0014360894097, 118.566230197483 37.0021034071181, 118.567555609809 37.0024663628472, 118.56757297092 37.0033913845486, 118.567564832899 37.0064013671875, 118.571159939236 37.0061526150174, 118.571012369792 37.0042765299479, 118.571185709635 37.0041286892361, 118.579192979601 37.0037060546875, 118.57921875 37.0023901367188, 118.584489746094 37.002063530816, 118.587507324219 37.0017963324653, 118.589874945747 37.001243218316, 118.59023030599 37.0013517252604, 118.590681694878 37.0035622829861, 118.590629611545 37.0036187065972, 118.590560167101 37.0036317274306, 118.589805772569 37.0041012912326, 118.588860405816 37.0043798828125, 118.585912000868 37.0049726019965, 118.58651936849 37.0079820421007, 118.58354546441 37.0084274631076, 118.583623318142 37.0088053385417, 118.584568413628 37.0093212890625, 118.584976128472 37.0097683376736, 118.585149739583 37.0109497070313, 118.585115017361 37.0118356662326, 118.586285536024 37.0118174913194, 118.586372612847 37.0148011610243, 118.584907226563 37.0149197048611, 118.585627170139 37.0161829969618, 118.588055284288 37.0158165147569, 118.588419596354 37.0174058702257, 118.585904676649 37.0177593315972, 118.585228407118 37.018020562066, 118.583910590278 37.018251953125, 118.581734483507 37.018401421441, 118.576767849392 37.0182373046875, 118.57668999566 37.0200702582465, 118.571906738281 37.0200808376736, 118.571456163194 37.0221012369792, 118.570061577691 37.0223244900174, 118.565998806424 37.0224742296007, 118.565912000868 37.0228784179687, 118.564162597656 37.0230550130208, 118.563270399306 37.0229782443576, 118.562586263021 37.0226451280382, 118.562092556424 37.0221856011285, 118.56142578125 37.0221823459201, 118.561400010851 37.0234724934896, 118.557425672743 37.0235148111979, 118.556282823351 37.0237646484375, 118.545827094184 37.023522406684, 118.546086697049 37.0252289496528, 118.544572482639 37.0251109483507, 118.545524631076 37.0290174696181, 118.545689290365 37.0293646918403, 118.546182725694 37.0310443793403, 118.547013617622 37.0340565321181, 118.545698242187 37.0342898220486, 118.546209038628 37.0363343641493, 118.545084364149 37.0365543619792, 118.545430501302 37.0385080295139, 118.547550726997 37.0384160698785, 118.549013400608 37.0387516276042, 118.550173068576 37.0389314778646, 118.552267795139 37.0386271158854, 118.55263156467 37.0413929578993, 118.558232693142 37.0407126193576, 118.557964138455 37.0396055772569, 118.55857014974 37.0392917209201, 118.559106987847 37.0388953993056, 118.560431857639 37.0387453884549, 118.560120442708 37.0411173502604, 118.560068359375 37.0414214409722, 118.56064860026 37.0420719401042, 118.561350368924 37.0448546006944, 118.561462944878 37.0454668511285, 118.559783257378 37.0458175998264, 118.560562879774 37.0487174479167, 118.560276963976 37.0487657335069, 118.558744574653 37.0489076063368, 118.559065212674 37.0514217122396, 118.557567274306 37.0514507378472, 118.557593315972 37.0515852864583, 118.55775797526 37.0533091905382, 118.557602267795 37.0538001844618, 118.557740885417 37.0560411241319, 118.557766927083 37.0569444444444, 118.558416341146 37.0569086371528, 118.559975043403 37.0568535698785, 118.56131781684 37.0633094618056, 118.56460015191 37.0639637586806, 118.567753092448 37.0645841471354, 118.567718370226 37.0644235568576, 118.567614474826 37.0633509657118, 118.570403917101 37.0630034722222, 118.570733235677 37.0642670355903, 118.572821180556 37.0643855794271, 118.573999565972 37.0638758680556, 118.575264756944 37.0636876085069, 118.580413140191 37.0633083767361, 118.580751681858 37.0666956922743, 118.583100857205 37.0669235568576, 118.585806206597 37.0673426649306, 118.587384440104 37.0676500108507, 118.591443413628 37.0684554036458, 118.592302246094 37.0683289930556, 118.597533637153 37.0676147460938, 118.598826226128 37.0650735134549, 118.600665961372 37.0650168185764, 118.601681315104 37.0649169921875, 118.601464301215 37.0633577473958, 118.603981119792 37.0632359483507, 118.604259168837 37.0639569769965, 118.607497016059 37.0636751302083, 118.607462293837 37.0634144422743, 118.61091796875 37.0630246310764, 118.610683322483 37.0618302408854, 118.615129665799 37.0626093207465, 118.615460069444 37.0637215169271, 118.631882324219 37.0667407226562, 118.632152235243 37.0704242621528, 118.636281467014 37.0703944227431, 118.638202853733 37.0703578016493, 118.641967773438 37.0700547960069, 118.640811360677 37.0725070529514, 118.643976779514 37.0729546440972, 118.647438151042 37.0737632921007, 118.648681911892 37.0740215386285, 118.648568793403 37.0748334418403, 118.648290744358 37.076005859375, 118.648282063802 37.0769222005208, 118.648290744358 37.0770524088542, 118.654109700521 37.0769490559896, 118.655485297309 37.0826763237847, 118.665167914497 37.0817599826389, 118.665403103299 37.0826812065972, 118.666029730903 37.0851841905382, 118.666377766927 37.0862532552083, 118.668100857205 37.0878721788194, 118.668718532986 37.0885118272569, 118.666647949219 37.0887510850694, 118.667004665799 37.0901025390625, 118.668222927517 37.0903436957465, 118.668388400608 37.0915383572049, 118.663986002604 37.0923160807292, 118.663977322049 37.0924812825521, 118.663464626736 37.0983089192708, 118.663638509115 37.0985218641493, 118.663899739583 37.0986962890625, 118.664134657118 37.098713921441, 118.663865288628 37.1020534939236, 118.668171929253 37.1015445963542, 118.668502604167 37.1015147569444, 118.668432888455 37.1020792643229, 118.667372233073 37.1092130533854, 118.666946343316 37.1121918402778, 118.667077094184 37.1139076063368, 118.667372775608 37.1141121419271, 118.670087619358 37.114951171875, 118.670600857205 37.1151692708333, 118.670670572917 37.1152650282118, 118.670914171007 37.115791015625, 118.670983886719 37.1160560438368, 118.671453721788 37.1167735460069, 118.671645236545 37.116943359375, 118.670966525608 37.1171199544271, 118.671784667969 37.1186027018229, 118.673907877604 37.1216295030382, 118.669105360243 37.1230059136285, 118.669662543403 37.1261512586806, 118.670750868056 37.1325984700521, 118.671969672309 37.1400577799479, 118.672143825955 37.1405447048611, 118.673414442274 37.1430834960938, 118.673719075521 37.1443218315972, 118.667672254774 37.1461735026042, 118.666497395833 37.1438693576389, 118.657902289497 37.1474237738715, 118.653613823785 37.1496877712674, 118.653143988715 37.1495393880208, 118.651725802951 37.1458018663194, 118.650055881076 37.1463376193576, 118.650569118924 37.1471115451389, 118.651891818576 37.1518996853299, 118.652683648003 37.1552408854167, 118.652936197917 37.1579470486111, 118.650511322215 37.1587161096567, 118.651367358233 37.1616036827537, 118.651171198349 37.1618313272211, 118.650188259549 37.1634450954861, 118.649727376302 37.1638742404514, 118.649196777344 37.16423828125, 118.648779296875 37.1642721896701, 118.64833577474 37.1639979383681, 118.647639702691 37.1622119140625, 118.646596137153 37.1624533420139, 118.645684994555 37.1595673925375, 118.63622398824 37.1615003559942, 118.636648763021 37.1630300564236, 118.634153645833 37.1633569335937, 118.63478000217 37.1658157009549, 118.634223632813 37.1671918402778, 118.634171549479 37.1677129448785, 118.633633083767 37.1711824544271, 118.636866861979 37.1711124674479, 118.638701443142 37.1711279296875, 118.639640842014 37.1749074978299, 118.643049587674 37.1749688042535, 118.643919542101 37.1783534071181, 118.645467393663 37.1781515842014, 118.647807617187 37.1854641384549, 118.648346896701 37.1853868272569, 118.649295247396 37.1891102430556, 118.649808485243 37.189045952691, 118.650147569444 37.1890812174479, 118.650339084201 37.1891946072049, 118.650495605469 37.1895334201389, 118.650921766493 37.1896036783854, 118.652739066946 37.1886993785832, 118.654574924045 37.1874861653646, 118.654383680556 37.1886973741319, 118.654644639757 37.1901483832465, 118.660386013455 37.1878957790799, 118.660769042969 37.1899899631076, 118.660839029948 37.1929953342014, 118.662552897135 37.1929418945313, 118.663431803385 37.1947805447049, 118.665032552083 37.194401312934, 118.665424262153 37.1965649414063, 118.667129720052 37.1966026475694, 118.667138400608 37.1971457248264, 118.667355957031 37.1975412326389, 118.667930230035 37.1980069986979, 118.668260904948 37.1980900065104, 118.66853922526 37.1982253689236, 118.668791503906 37.198447265625, 118.668843858507 37.1987513563368, 118.668826497396 37.1989987521701, 118.668730740017 37.199137641059, 118.668522135417 37.1993977864583, 118.668087022569 37.1995402018229, 118.66750406901 37.1997129991319, 118.666947157118 37.2001331922743, 118.666842990451 37.2003415256076, 118.666877712674 37.2005194769965, 118.667121310764 37.2008848741319, 118.667521701389 37.2012546115451, 118.668992241753 37.2023388671875, 118.669818793403 37.2030265299479, 118.670053710937 37.203196343316, 118.67036702474 37.2031882052951, 118.6712109375 37.2026904296875, 118.67156765408 37.2027039930556, 118.671915690104 37.2028393554687, 118.672568359375 37.2029361979167, 118.673327907986 37.2030872938368, 118.673031141493 37.2038186306424, 118.672297905816 37.2036781141493, 118.671878526476 37.2043047417535, 118.67166937934 37.2049319118924, 118.671931152344 37.2056296115451, 118.672018500434 37.2064143880208, 118.671948784722 37.2076345486111, 118.67200141059 37.2083319769965, 118.672455512153 37.208977593316, 118.672647569444 37.209710015191, 118.672490505642 37.2105466037326, 118.672159016927 37.2113826497396, 118.672316080729 37.212219780816, 118.672817382812 37.2127218967014, 118.672845323351 37.2133772786458, 118.672119140625 37.2142545572917, 118.67210530599 37.2147148980035, 118.672343478733 37.2151478407118, 118.673320855035 37.2162651909722, 118.673977593316 37.2170613606771, 118.674592285156 37.2184847005208, 118.675031195747 37.2189401584201, 118.675793999566 37.2192960611979, 118.67696234809 37.2196964518229, 118.677660861545 37.2201999240451, 118.678177897135 37.2210234917535, 118.678457573785 37.221875, 118.678513454861 37.2228648546007, 118.678331705729 37.2237711588542, 118.678052571615 37.2242727322049, 118.677577853733 37.2247374131944, 118.676701931424 37.2254766167535, 118.676147460938 37.2261447482639, 118.675494791667 37.2269203016493, 118.675146213108 37.2275531684028, 118.67498453776 37.2280523003472, 118.674772677951 37.2288102213542, 118.677125651042 37.2289181857639, 118.680630425347 37.2292857530382, 118.68279812283 37.2300832790799, 118.685833062066 37.2320364040799, 118.688831651476 37.2334483506944, 118.692505696615 37.2349888780382, 118.700428331163 37.2377967664931, 118.704120008681 37.238952094184, 118.707051323785 37.2401380750868, 118.709710557726 37.2412741427951, 118.711365559896 37.2424943033854, 118.71326171875 37.2447810872396, 118.714296603733 37.245651312934, 118.721662597656 37.2496210394965, 118.728425021701 37.2527642144097, 118.735143229167 37.2565700954861, 118.736472710503 37.2571834309896, 118.743666178385 37.261373969184, 118.754669325087 37.2674869791667, 118.759548068576 37.2702964952257, 118.766161295573 37.2736645507812, 118.766655815972 37.2739206271701, 118.771245659722 37.2767540147569, 118.777976888021 37.2801106770833, 118.779711371528 37.2804695638021, 118.782858886719 37.2806361219618, 118.78701171875 37.2802281358507, 118.786977267795 37.2812269422743, 118.806953667535 37.2858113606771, 118.821896701389 37.2887687174479, 118.840726182726 37.2914561631944, 118.845316840278 37.2921034071181, 118.856959092882 37.2938503689236, 119.039890136719 37.3044664171007))";
        //String wkt1 = "LINESTRING(119.039890136719 37.3044664171007, 119.035866427951 37.3061189778646, 119.030822753906 37.3081287977431, 119.02196234809 37.3102964952257, 119.010303548177 37.3132101779514, 119.001206325955 37.3187581380208, 118.993556043837 37.3273980034722, 118.986952853733 37.3395109049479, 118.98312906901 37.350016547309, 118.981622721354 37.358792046441, 118.981431206597 37.3598250325521, 118.963889702691 37.3569094509549, 118.958857421875 37.3558213975694, 118.950144856771 37.3536802842882, 118.944419759115 37.35193359375, 118.940392252604 37.3509676106771, 118.936956922743 37.3501508246528, 118.932513834635 37.3500716145833, 118.928871527778 37.3502501085069, 118.926707085503 37.3505520290799, 118.922336425781 37.3517125108507, 118.916750488281 37.3539499240451, 118.914483506944 37.3551255967882, 118.908639865451 37.3574085828993, 118.906834038628 37.3583506944444, 118.905965983073 37.3591799587674, 118.904837510851 37.358359375, 118.903457302517 37.3571698676215, 118.903005642361 37.3563709852431, 118.902918836806 37.3555590820312, 118.90298828125 37.3540828450521, 118.902658148872 37.3513690863715, 118.902484266493 37.3497970920139, 118.901789822049 37.3483732096354, 118.900314127604 37.345625, 118.89896891276 37.3443617078993, 118.897406955295 37.3432638888889, 118.895307074653 37.3423182508681, 118.89095187717 37.3406968858507, 118.888636067708 37.3398689778646, 118.887005208333 37.3388671875, 118.885860460069 37.3376871744792, 118.884594184028 37.335530327691, 118.882330457899 37.3315983072917, 118.881324598524 37.3301185438368, 118.880119357639 37.3290896267361, 118.879157172309 37.3287369791667, 118.878136664497 37.3287182617187, 118.877050238715 37.3288772243924, 118.875862901476 37.3294300672743, 118.873635253906 37.3307180447049, 118.871199815538 37.3315766059028, 118.869665798611 37.3317523871528, 118.866708170573 37.331530219184, 118.864697265625 37.3312136501736, 118.862508138021 37.3308596462674, 118.860879177517 37.3308884006076, 118.859770236545 37.3309073893229, 118.857517632378 37.3312543402778, 118.855888943142 37.3315825737847, 118.851965060764 37.332848578559, 118.85049235026 37.3332071940104, 118.850163302951 37.3332381184896, 118.835256890191 37.3326969401042, 118.831861979167 37.3325729709201, 118.825799153646 37.3325105794271, 118.821823730469 37.3322789171007, 118.819129774306 37.3314718967014, 118.818324110243 37.331243218316, 118.816892903646 37.3305124240451, 118.814613172743 37.3298285590278, 118.812798936632 37.3295857747396, 118.807331000434 37.3297667100694, 118.803064507378 37.329625922309, 118.798454047309 37.3290182834201, 118.794315863715 37.3284282769097, 118.791940917969 37.3281966145833, 118.788820529514 37.3284654405382, 118.784624565972 37.3289474826389, 118.781277669271 37.3295195855035, 118.777600911458 37.3298787434896, 118.773350965712 37.3298426649306, 118.768753255208 37.3294458007813, 118.763122558594 37.3288636610243, 118.759388834635 37.3283333333333, 118.757423502604 37.3280780707465, 118.75485921224 37.3278209092882, 118.75100124783 37.3278206380208, 118.748912489149 37.3277954101562, 118.747609592014 37.327451171875, 118.746060926649 37.3267130533854, 118.742864854601 37.3243519422743, 118.740652126736 37.3233430989583, 118.738021375868 37.3229728190104, 118.734480251736 37.3226996527778, 118.730298936632 37.3223027886285, 118.728478732639 37.3220798068576, 118.725199652778 37.326569281684, 118.721975097656 37.3301087782118, 118.720949164497 37.3316663953993, 118.719454210069 37.3341178385417, 118.71743733724 37.3370505099826, 118.701199544271 37.3372254774306, 118.701190863715 37.3380938042535, 118.696876085069 37.3381079101563, 118.696101616753 37.3381065538194, 118.697014973958 37.3370705837674, 118.695701497396 37.3371158854167, 118.695657823351 37.3363427734375, 118.687409667969 37.3364927842882, 118.684921332465 37.3365793185764, 118.684851616753 37.3352547200521, 118.676637641059 37.3353214518229, 118.681292317708 37.3295640733507, 118.677707248264 37.3294398328993, 118.677681206597 37.3305471462674, 118.678953450521 37.330612250434, 118.67879828559 37.3322688802083, 118.67656765408 37.3322992621528, 118.676524251302 37.3311181640625, 118.672434624566 37.3311146375868, 118.672356228299 37.3293123372396, 118.676880696615 37.3295079210069, 118.679577636719 37.3255007595486, 118.666891547309 37.3253550889757, 118.663420681424 37.3303854709201, 118.66208062066 37.3294930013021, 118.661393500434 37.3291965060764, 118.659601508247 37.3312253146701, 118.639752604167 37.3213538953993, 118.638065321181 37.3168052842882, 118.636952039931 37.3118145073785, 118.635552300347 37.3113351779514, 118.63469156901 37.3113384331597, 118.630736490885 37.3113425021701, 118.623106282552 37.3112961154514, 118.620291341146 37.3112331814236, 118.602689615885 37.3112906901042, 118.602368977865 37.3144487847222, 118.599557020399 37.3147531467014, 118.59567843967 37.3154009331597, 118.595486653646 37.3057524956597, 118.585061306424 37.3056236436632, 118.585200737847 37.3140044487847, 118.58373562283 37.3139925130208, 118.583751898872 37.3056073676215, 118.580188802083 37.3055631510417, 118.579460720486 37.3055419921875, 118.579635687934 37.3192941623264, 118.57156765408 37.3211797417535, 118.566794433594 37.3221508789062, 118.566871744792 37.3155767144097, 118.562047526042 37.3157194010417, 118.562073567708 37.314342719184, 118.562176649306 37.3079418945312, 118.562193739149 37.3057405598958, 118.562202419705 37.3050716145833, 118.555084364149 37.2990842013889, 118.554452582465 37.2990161132812, 118.554574652778 37.3081868489583, 118.554739583333 37.3116691080729, 118.553908420139 37.3118573676215, 118.551190592448 37.3124452039931, 118.550289171007 37.2993636067708, 118.552530653212 37.298994140625, 118.553586697049 37.2988354492187, 118.553915744358 37.2988389756944, 118.554755588108 37.2989154730903, 118.554876573351 37.2987242296007, 118.55459906684 37.2925846354167, 118.550946180556 37.2930788845486, 118.550477701823 37.2840171983507, 118.55042561849 37.2826451280382, 118.549118923611 37.2831212022569, 118.5491796875 37.2845974392361, 118.547673882378 37.286598578559, 118.545052083333 37.2896790907118, 118.545147840712 37.292497016059, 118.543797743056 37.2925480143229, 118.54364203559 37.2912586805556, 118.542266438802 37.2927213541667, 118.541695421007 37.2931873914931, 118.54075249566 37.2937584092882, 118.538183051215 37.2950895182292, 118.523833821615 37.2947596571181, 118.524025065104 37.3037217881944, 118.523013237847 37.3039114040799, 118.518058539497 37.3045817057292, 118.514262695312 37.304970703125, 118.511426595052 37.305439453125, 118.51048421224 37.3055810546875, 118.510319010417 37.2956287977431, 118.50709391276 37.2961596679688, 118.50705078125 37.2961686197917, 118.506506076389 37.2962874348958, 118.480116102431 37.3011672634549, 118.479190538194 37.3013172743056, 118.478801540799 37.3008797200521, 118.478126627604 37.3001131184896, 118.477763400608 37.2991674804688, 118.475116373698 37.299130859375, 118.470289442274 37.298756781684, 118.468662923177 37.299030219184, 118.468602430556 37.2998684353299, 118.470064832899 37.3025352647569, 118.470508897569 37.3036146375868, 118.465323621962 37.3034022352431, 118.462753634983 37.3032082790799, 118.457379286024 37.3036325412326, 118.456989474826 37.3027129448785, 118.452478298611 37.2916357421875, 118.452322319878 37.2912537977431, 118.443385687934 37.2911520724826, 118.442736002604 37.2904234483507, 118.442181803385 37.2907717556424, 118.446496039497 37.3011344401042, 118.446807996962 37.3019460720486, 118.44172390408 37.3006252712674, 118.437149522569 37.2999194335938, 118.431187608507 37.2996264648437, 118.430979546441 37.2991490342882, 118.428985460069 37.2946826171875, 118.42521484375 37.2958148871528, 118.423731825087 37.2929760742187, 118.421451280382 37.2932988823785, 118.421295572917 37.2945060221354, 118.422691786024 37.2976578776042, 118.422821994358 37.2985782877604, 118.418815375434 37.2966438802083, 118.415640733507 37.2946997070312, 118.414755588108 37.2925678168403, 118.413914116753 37.2914434136285, 118.413098415799 37.2897802734375, 118.411588812934 37.289797905816, 118.409662543403 37.2898285590278, 118.409576009115 37.2927205403646, 118.405670572917 37.2893288845486, 118.405348849826 37.2849386935764, 118.405600585938 37.2843004014757, 118.407145182292 37.2843050130208, 118.407049696181 37.2825461154514, 118.402310655382 37.2819243706597, 118.401728244358 37.2769346788194, 118.396927354601 37.2768893771701, 118.397795138889 37.2729337565104, 118.397508409288 37.2720912000868, 118.395936686198 37.2717952473958, 118.391429578993 37.2721180555556, 118.391090766059 37.2712839084201, 118.391593695747 37.2644840494792, 118.390655381944 37.2621253797743, 118.389092068142 37.2617635091146, 118.383210720486 37.2623532443576, 118.376858452691 37.2620030381944, 118.375911187066 37.262001953125, 118.375815429688 37.2596959092882, 118.375763075087 37.2584971788194, 118.368374565972 37.2585782877604, 118.367348632812 37.2560799153646, 118.367061631944 37.2552761501736, 118.364296875 37.2544943576389, 118.360330946181 37.2445781792535, 118.358678656684 37.2437849934896, 118.355217827691 37.243857421875, 118.350443250868 37.243779296875, 118.347520345052 37.2371253797743, 118.346641438802 37.233258734809, 118.346884765625 37.2318391927083, 118.347789171007 37.2313587782118, 118.354998914931 37.2317540147569, 118.35375515408 37.23107421875, 118.349928385417 37.2288568793403, 118.355519476997 37.2202639431424, 118.358067220052 37.2191566297743, 118.360188530816 37.2177010091146, 118.363465983073 37.2124297417535, 118.364195963542 37.2101814778646, 118.36682156033 37.2099986436632, 118.371350640191 37.2087239583333, 118.371915418837 37.2082470703125, 118.371923828125 37.2063709852431, 118.375930718316 37.2061157226562, 118.376730143229 37.2040451388889, 118.37666015625 37.2016132269965, 118.377485894097 37.2016357421875, 118.377572699653 37.2011539713542, 118.376598849826 37.1969661458333, 118.379414605035 37.1963658311632, 118.380083007813 37.1919976128472, 118.381264648437 37.1911303710937, 118.383393554688 37.1905897352431, 118.382680664063 37.1879486762153, 118.382446017795 37.1870277235243, 118.38434000651 37.1861653645833, 118.384096137153 37.1823999023437, 118.387067328559 37.1823548719618, 118.387605794271 37.1810175238715, 118.387562120226 37.1778211805556, 118.383913302951 37.1783390299479, 118.383548177083 37.1751638454861, 118.38046359592 37.1751779513889, 118.380775824653 37.1704836697049, 118.378837890625 37.1700645616319, 118.378515896267 37.1656342230903, 118.377655436198 37.1655552842882, 118.377584906684 37.15568359375, 118.377575954861 37.1541764322917, 118.376941460503 37.1541365559896, 118.371883138021 37.154108344184, 118.371673990885 37.1496956380208, 118.371065538194 37.1494775390625, 118.367979600694 37.1501896158854, 118.36660563151 37.1468001302083, 118.366414388021 37.1468606228299, 118.364153917101 37.1477473958333, 118.36157172309 37.1484860568576, 118.36128499349 37.1481553819444, 118.356788736979 37.1430753580729, 118.356510416667 37.1413766818576, 118.35620578342 37.1393348524306, 118.347622070312 37.1398234049479, 118.346586914062 37.1378800455729, 118.346056043837 37.134313422309, 118.343872884115 37.1342659505208, 118.342150878906 37.1336328125, 118.341037326389 37.1328187391493, 118.34069797092 37.1317279730903, 118.341349826389 37.127946234809, 118.342254231771 37.1260934787326, 118.346020507812 37.1269300672743, 118.346507432726 37.1269745551215, 118.346315917969 37.1245939127604, 118.346081000434 37.1239116753472, 118.345341525608 37.1239016384549, 118.34005343967 37.1237396918403, 118.338244357639 37.1231195746528, 118.34012234158 37.1164694552951, 118.342653537326 37.1188541666667, 118.346506076389 37.1151220703125, 118.346349283854 37.1128285047743, 118.344922688802 37.1114404296875, 118.344896375868 37.110081108941, 118.346488172743 37.1101144748264, 118.34719265408 37.1097203233507, 118.348827582465 37.1083726671007, 118.349566514757 37.1070450846354, 118.349983723958 37.1037841796875, 118.34936577691 37.101754828559, 118.346069607205 37.101887749566, 118.342599555122 37.104208984375, 118.342025553385 37.10388671875, 118.341538085938 37.1010017903646, 118.338528917101 37.1027419704861, 118.338259849805 37.1030906597372, 118.334083518739 37.102983241172, 118.334014756944 37.1017692057292, 118.336824001736 37.1018267144097, 118.337163085938 37.1008110894097, 118.336875813802 37.0985302734375, 118.339058973524 37.0969797092014, 118.338832465278 37.0938826497396, 118.342476671007 37.0938547092014, 118.342989637587 37.0922661675347, 118.342336968316 37.0892854817708, 118.336979166667 37.0888755967882, 118.336648220486 37.0859695095486, 118.334482421875 37.0844973415799, 118.332942437066 37.0819360351562, 118.332628851997 37.0778439670139, 118.334785970052 37.0775528971354, 118.336603190104 37.0733216688368, 118.337455512153 37.0723635525174, 118.338542751736 37.0722612847222, 118.337063530816 37.0670901150174, 118.336114908854 37.0617895507812, 118.33565375434 37.0601597764757, 118.336123046875 37.0574419487847, 118.337523328993 37.0566582573785, 118.33762749566 37.055403374566, 118.337557779948 37.0539005533854, 118.33043375651 37.0500952148438, 118.324562445747 37.046279296875, 118.324214138455 37.0429082573785, 118.325440266927 37.0405390082465, 118.326588270399 37.0402674696181, 118.326744791667 37.0396034071181, 118.325865885417 37.0354408094618, 118.323613009983 37.0326133897569, 118.319081488715 37.0292955186632, 118.3158984375 37.0283775499132, 118.311567925347 37.0286653645833, 118.310150282118 37.0282373046875, 118.308584798177 37.0245993381076, 118.308367241753 37.0215323893229, 118.308201768663 37.0199034288194, 118.306366916233 37.0183846028646, 118.301176757812 37.0186458333333, 118.299490288628 37.0181914605035, 118.298168945312 37.0162828233507, 118.297525227865 37.0130330403646, 118.295995551215 37.0131089952257, 118.295004340278 37.0120697699653, 118.294412977431 37.0089982096354, 118.28998969184 37.0094571940104, 118.289102376302 37.0015600585938, 118.289023980035 37.0007866753472, 118.288968395371 37.0005632053882, 118.2889545 37.00050557, 118.28882405599 36.9999829101562, 118.289718967014 36.9976038953993, 118.291639268663 36.995881890191, 118.292923719618 36.9816417100694, 118.293475748698 36.9776733398437, 118.293462456597 36.9776483832465, 118.29348171658 36.9776304796007, 118.294591200087 36.9696560329861, 118.305448676215 36.96998046875, 118.30872639974 36.9704245334201, 118.312491590712 36.9709044053819, 118.312500542535 36.9722856987847, 118.313917914497 36.972444390191, 118.318040093316 36.9728515625, 118.317996690538 36.9745496961806, 118.322345106337 36.9745054796007, 118.322300889757 36.9671085611979, 118.324727376302 36.9673044162326, 118.32465766059 36.9647675238715, 118.328084309896 36.9635579427083, 118.334259440104 36.9620233832465, 118.340843641493 36.9610891384549, 118.344278971354 36.9607134331597, 118.344870876736 36.9636159939236, 118.350314823636 36.9672313455237, 118.350313873063 36.9674817502144, 118.350865246511 36.9677925634584, 118.351168348524 36.9720711263021, 118.352220865885 36.9726245117187, 118.352299262153 36.9745792643229, 118.361264648437 36.9747856987847, 118.361690809462 36.9747734917535, 118.370836588542 36.9745005967882, 118.372036132812 36.9748887803819, 118.375677897135 36.9749197048611, 118.381639268663 36.9748353407118, 118.384680175781 36.974377983941, 118.384532063802 36.9715676540799, 118.387590060764 36.9712969292535, 118.386981336806 36.9673090277778, 118.387789171007 36.9661325412326, 118.387406684028 36.9634350585938, 118.388787706163 36.9631016710069, 118.386745605469 36.9560158962674, 118.387179904514 36.9553735351562, 118.38850016276 36.9550618489583, 118.389099392361 36.9537421332465, 118.386354672901 36.9512395051342, 118.386527031949 36.9504736783567, 118.390332302517 36.9480748155382, 118.392789984809 36.9475249565972, 118.394622395833 36.9483642578125, 118.396836751302 36.9491126844618, 118.397201605903 36.9492171223958, 118.397548828125 36.9492561848958, 118.39782687717 36.9494517686632, 118.398356391059 36.9495431857639, 118.39860812717 36.9491655815972, 118.401794433594 36.9498095703125, 118.401924099392 36.9456876627604, 118.403234592014 36.9431426323785, 118.407001139323 36.9418446180556, 118.410333387587 36.9418229166667, 118.421158854167 36.9416848415799, 118.422399088542 36.9422922092014, 118.423002105098 36.9438269639495, 118.429518769732 36.9440105910473, 118.434179416233 36.9446964518229, 118.439100477431 36.9422189670139, 118.462945963542 36.9466487630208, 118.462876790365 36.9459106445313, 118.46231391059 36.9424370659722, 118.462452256944 36.9413986545139, 118.465714518229 36.9412608506944, 118.466164279514 36.9412467447917, 118.466347113715 36.9416528320313, 118.466361219618 36.9416918945313, 118.46637749566 36.9417198350694, 118.466571180556 36.9421492513021, 118.467376302083 36.9454961480035, 118.467635904948 36.9465638563368, 118.467835015191 36.9475320095486, 118.470231662326 36.947916937934, 118.47149468316 36.9488997395833, 118.472706163194 36.9507600911458, 118.473735894097 36.9539279513889, 118.474506022135 36.9560327148438, 118.476659884983 36.9570912000868, 118.486666395399 36.9566419813368, 118.489640842014 36.9549525282118, 118.493549262153 36.9547892252604, 118.496696506076 36.9538633897569, 118.497491861979 36.9519194878472, 118.503362630208 36.9515717230903, 118.50376030816 36.9515443250868, 118.503717176649 36.9503588867188, 118.503189019097 36.9442667643229, 118.506457248264 36.9438180881076, 118.507823079427 36.9430018446181, 118.512682562934 36.9429047309028, 118.514947916667 36.943805609809, 118.521355523003 36.9438563368056, 118.52144863828 36.9452496622572, 118.524557255228 36.945278949473, 118.524935709635 36.9447580295139, 118.525359429253 36.9441921657986, 118.525368109809 36.9436363389757, 118.525644802517 36.9430710177951, 118.525800238715 36.9425056966146, 118.526076931424 36.9419447157118, 118.526638997396 36.9413785807292, 118.526872558594 36.9408306206597, 118.526933051215 36.9402571614583, 118.527080078125 36.9396964518229, 118.528948025174 36.9393088107639, 118.530781521267 36.9391343858507, 118.534890136719 36.9373771158854, 118.537753363715 36.9367702907986, 118.544562445747 36.9363492838542, 118.54541937934 36.9373027886285, 118.548534884983 36.9370393880208, 118.549244520399 36.9387882486979, 118.551564618918 36.9387638082809, 118.554642932554 36.9383723494501, 118.554897148659 36.9423072837816, 118.553694118924 36.9423749457465, 118.553901909722 36.9438338216146, 118.554603135851 36.9441710069444, 118.555295681424 36.9445171440972, 118.555711263021 36.9449679904514, 118.555988498264 36.9455276150174, 118.55626546224 36.9460959201389, 118.556404079861 36.9466517469618, 118.557096896701 36.9468893771701, 118.55779812283 36.9467751736111, 118.558499348958 36.9467738172743, 118.5607421875 36.9465608723958, 118.560785590278 36.9490410698785, 118.562197536892 36.9513359917535, 118.562206217448 36.9524392361111, 118.560353461372 36.9556784396701, 118.558361816406 36.9562773980035, 118.558102484809 36.9589057074653, 118.5584542232 36.9617376673028, 118.555995761199 36.9631584991552, 118.555900999097 36.9632785373264, 118.55581841 36.963428, 118.557462565104 36.9653870985243, 118.558406846788 36.9702368164062, 118.558649359809 36.9708881293403, 118.559420301649 36.9747694227431, 118.55974093967 36.9760677083333, 118.559818793403 36.9770578342014, 118.558442382813 36.9795448133681, 118.557446831597 36.9798291015625, 118.554572482639 36.9795654296875, 118.552295735677 36.9796657986111, 118.553049587674 36.9855886501736, 118.553110351562 36.9867613389757, 118.551725531684 36.9878762478299, 118.552747667101 36.9943717447917, 118.553007541233 36.9965687391493, 118.55399468316 37.0002454969618, 118.554869249132 37.0005476888021, 118.55705078125 37.0005780707465, 118.557570258247 37.0005989583333, 118.55983859592 36.998987358941, 118.560098198785 36.9961376953125, 118.564133300781 36.9941802300347, 118.566697048611 36.9940893554688, 118.567121582031 36.9940104166667, 118.56752875434 36.9946134440104, 118.575023057726 36.9939469401042, 118.57481499566 36.992249077691, 118.576011013455 36.9921780056424, 118.576695963542 36.9958387586806, 118.578533257378 36.9957063802083, 118.579304741753 36.9951190863715, 118.580466308594 36.9950179036458, 118.581185980903 36.996494140625, 118.57940890842 36.9974948459201, 118.579383138021 36.9983764648438, 118.574460449219 36.9989729817708, 118.573524305556 36.9965201822917, 118.571540256076 36.9971440972222, 118.570760633681 36.9979747178819, 118.568100857205 36.9985302734375, 118.566212565104 36.9990326605903, 118.566134982639 37.0006008572049, 118.56611843533 37.0010061306424, 118.566169704861 37.0013593207465, 118.566187879774 37.0014360894097, 118.566230197483 37.0021034071181, 118.567555609809 37.0024663628472, 118.56757297092 37.0033913845486, 118.567564832899 37.0064013671875, 118.571159939236 37.0061526150174, 118.571012369792 37.0042765299479, 118.571185709635 37.0041286892361, 118.579192979601 37.0037060546875, 118.57921875 37.0023901367188, 118.584489746094 37.002063530816, 118.587507324219 37.0017963324653, 118.589874945747 37.001243218316, 118.59023030599 37.0013517252604, 118.590681694878 37.0035622829861, 118.590629611545 37.0036187065972, 118.590560167101 37.0036317274306, 118.589805772569 37.0041012912326, 118.588860405816 37.0043798828125, 118.585912000868 37.0049726019965, 118.58651936849 37.0079820421007, 118.58354546441 37.0084274631076, 118.583623318142 37.0088053385417, 118.584568413628 37.0093212890625, 118.584976128472 37.0097683376736, 118.585149739583 37.0109497070313, 118.585115017361 37.0118356662326, 118.586285536024 37.0118174913194, 118.586372612847 37.0148011610243, 118.584907226563 37.0149197048611, 118.585627170139 37.0161829969618, 118.588055284288 37.0158165147569, 118.588419596354 37.0174058702257, 118.585904676649 37.0177593315972, 118.585228407118 37.018020562066, 118.583910590278 37.018251953125, 118.581734483507 37.018401421441, 118.576767849392 37.0182373046875, 118.57668999566 37.0200702582465, 118.571906738281 37.0200808376736, 118.571456163194 37.0221012369792, 118.570061577691 37.0223244900174, 118.565998806424 37.0224742296007, 118.565912000868 37.0228784179687, 118.564162597656 37.0230550130208, 118.563270399306 37.0229782443576, 118.562586263021 37.0226451280382, 118.562092556424 37.0221856011285, 118.56142578125 37.0221823459201, 118.561400010851 37.0234724934896, 118.557425672743 37.0235148111979, 118.556282823351 37.0237646484375, 118.545827094184 37.023522406684, 118.546086697049 37.0252289496528, 118.544572482639 37.0251109483507, 118.545524631076 37.0290174696181, 118.545689290365 37.0293646918403, 118.546182725694 37.0310443793403, 118.547013617622 37.0340565321181, 118.545698242187 37.0342898220486, 118.546209038628 37.0363343641493, 118.545084364149 37.0365543619792, 118.545430501302 37.0385080295139, 118.547550726997 37.0384160698785, 118.549013400608 37.0387516276042, 118.550173068576 37.0389314778646, 118.552267795139 37.0386271158854, 118.55263156467 37.0413929578993, 118.558232693142 37.0407126193576, 118.557964138455 37.0396055772569, 118.55857014974 37.0392917209201, 118.559106987847 37.0388953993056, 118.560431857639 37.0387453884549, 118.560120442708 37.0411173502604, 118.560068359375 37.0414214409722, 118.56064860026 37.0420719401042, 118.561350368924 37.0448546006944, 118.561462944878 37.0454668511285, 118.559783257378 37.0458175998264, 118.560562879774 37.0487174479167, 118.560276963976 37.0487657335069, 118.558744574653 37.0489076063368, 118.559065212674 37.0514217122396, 118.557567274306 37.0514507378472, 118.557593315972 37.0515852864583, 118.55775797526 37.0533091905382, 118.557602267795 37.0538001844618, 118.557740885417 37.0560411241319, 118.557766927083 37.0569444444444, 118.558416341146 37.0569086371528, 118.559975043403 37.0568535698785, 118.56131781684 37.0633094618056, 118.56460015191 37.0639637586806, 118.567753092448 37.0645841471354, 118.567718370226 37.0644235568576, 118.567614474826 37.0633509657118, 118.570403917101 37.0630034722222, 118.570733235677 37.0642670355903, 118.572821180556 37.0643855794271, 118.573999565972 37.0638758680556, 118.575264756944 37.0636876085069, 118.580413140191 37.0633083767361, 118.580751681858 37.0666956922743, 118.583100857205 37.0669235568576, 118.585806206597 37.0673426649306, 118.587384440104 37.0676500108507, 118.591443413628 37.0684554036458, 118.592302246094 37.0683289930556, 118.597533637153 37.0676147460938, 118.598826226128 37.0650735134549, 118.600665961372 37.0650168185764, 118.601681315104 37.0649169921875, 118.601464301215 37.0633577473958, 118.603981119792 37.0632359483507, 118.604259168837 37.0639569769965, 118.607497016059 37.0636751302083, 118.607462293837 37.0634144422743, 118.61091796875 37.0630246310764, 118.610683322483 37.0618302408854, 118.615129665799 37.0626093207465, 118.615460069444 37.0637215169271, 118.631882324219 37.0667407226562, 118.632152235243 37.0704242621528, 118.636281467014 37.0703944227431, 118.638202853733 37.0703578016493, 118.641967773438 37.0700547960069, 118.640811360677 37.0725070529514, 118.643976779514 37.0729546440972, 118.647438151042 37.0737632921007, 118.648681911892 37.0740215386285, 118.648568793403 37.0748334418403, 118.648290744358 37.076005859375, 118.648282063802 37.0769222005208, 118.648290744358 37.0770524088542, 118.654109700521 37.0769490559896, 118.655485297309 37.0826763237847, 118.665167914497 37.0817599826389, 118.665403103299 37.0826812065972, 118.666029730903 37.0851841905382, 118.666377766927 37.0862532552083, 118.668100857205 37.0878721788194, 118.668718532986 37.0885118272569, 118.666647949219 37.0887510850694, 118.667004665799 37.0901025390625, 118.668222927517 37.0903436957465, 118.668388400608 37.0915383572049, 118.663986002604 37.0923160807292, 118.663977322049 37.0924812825521, 118.663464626736 37.0983089192708, 118.663638509115 37.0985218641493, 118.663899739583 37.0986962890625, 118.664134657118 37.098713921441, 118.663865288628 37.1020534939236, 118.668171929253 37.1015445963542, 118.668502604167 37.1015147569444, 118.668432888455 37.1020792643229, 118.667372233073 37.1092130533854, 118.666946343316 37.1121918402778, 118.667077094184 37.1139076063368, 118.667372775608 37.1141121419271, 118.670087619358 37.114951171875, 118.670600857205 37.1151692708333, 118.670670572917 37.1152650282118, 118.670914171007 37.115791015625, 118.670983886719 37.1160560438368, 118.671453721788 37.1167735460069, 118.671645236545 37.116943359375, 118.670966525608 37.1171199544271, 118.671784667969 37.1186027018229, 118.673907877604 37.1216295030382, 118.669105360243 37.1230059136285, 118.669662543403 37.1261512586806, 118.670750868056 37.1325984700521, 118.671969672309 37.1400577799479, 118.672143825955 37.1405447048611, 118.673414442274 37.1430834960938, 118.673719075521 37.1443218315972, 118.667672254774 37.1461735026042, 118.666497395833 37.1438693576389, 118.657902289497 37.1474237738715, 118.653613823785 37.1496877712674, 118.653143988715 37.1495393880208, 118.651725802951 37.1458018663194, 118.650055881076 37.1463376193576, 118.650569118924 37.1471115451389, 118.651891818576 37.1518996853299, 118.652683648003 37.1552408854167, 118.652936197917 37.1579470486111, 118.650511322215 37.1587161096567, 118.651367358233 37.1616036827537, 118.651171198349 37.1618313272211, 118.650188259549 37.1634450954861, 118.649727376302 37.1638742404514, 118.649196777344 37.16423828125, 118.648779296875 37.1642721896701, 118.64833577474 37.1639979383681, 118.647639702691 37.1622119140625, 118.646596137153 37.1624533420139, 118.645684994555 37.1595673925375, 118.63622398824 37.1615003559942, 118.636648763021 37.1630300564236, 118.634153645833 37.1633569335937, 118.63478000217 37.1658157009549, 118.634223632813 37.1671918402778, 118.634171549479 37.1677129448785, 118.633633083767 37.1711824544271, 118.636866861979 37.1711124674479, 118.638701443142 37.1711279296875, 118.639640842014 37.1749074978299, 118.643049587674 37.1749688042535, 118.643919542101 37.1783534071181, 118.645467393663 37.1781515842014, 118.647807617187 37.1854641384549, 118.648346896701 37.1853868272569, 118.649295247396 37.1891102430556, 118.649808485243 37.189045952691, 118.650147569444 37.1890812174479, 118.650339084201 37.1891946072049, 118.650495605469 37.1895334201389, 118.650921766493 37.1896036783854, 118.652739066946 37.1886993785832, 118.654574924045 37.1874861653646, 118.654383680556 37.1886973741319, 118.654644639757 37.1901483832465, 118.660386013455 37.1878957790799, 118.660769042969 37.1899899631076, 118.660839029948 37.1929953342014, 118.662552897135 37.1929418945313, 118.663431803385 37.1947805447049, 118.665032552083 37.194401312934, 118.665424262153 37.1965649414063, 118.667129720052 37.1966026475694, 118.667138400608 37.1971457248264, 118.667355957031 37.1975412326389, 118.667930230035 37.1980069986979, 118.668260904948 37.1980900065104, 118.66853922526 37.1982253689236, 118.668791503906 37.198447265625, 118.668843858507 37.1987513563368, 118.668826497396 37.1989987521701, 118.668730740017 37.199137641059, 118.668522135417 37.1993977864583, 118.668087022569 37.1995402018229, 118.66750406901 37.1997129991319, 118.666947157118 37.2001331922743, 118.666842990451 37.2003415256076, 118.666877712674 37.2005194769965, 118.667121310764 37.2008848741319, 118.667521701389 37.2012546115451, 118.668992241753 37.2023388671875, 118.669818793403 37.2030265299479, 118.670053710937 37.203196343316, 118.67036702474 37.2031882052951, 118.6712109375 37.2026904296875, 118.67156765408 37.2027039930556, 118.671915690104 37.2028393554687, 118.672568359375 37.2029361979167, 118.673327907986 37.2030872938368, 118.673031141493 37.2038186306424, 118.672297905816 37.2036781141493, 118.671878526476 37.2043047417535, 118.67166937934 37.2049319118924, 118.671931152344 37.2056296115451, 118.672018500434 37.2064143880208, 118.671948784722 37.2076345486111, 118.67200141059 37.2083319769965, 118.672455512153 37.208977593316, 118.672647569444 37.209710015191, 118.672490505642 37.2105466037326, 118.672159016927 37.2113826497396, 118.672316080729 37.212219780816, 118.672817382812 37.2127218967014, 118.672845323351 37.2133772786458, 118.672119140625 37.2142545572917, 118.67210530599 37.2147148980035, 118.672343478733 37.2151478407118, 118.673320855035 37.2162651909722, 118.673977593316 37.2170613606771, 118.674592285156 37.2184847005208, 118.675031195747 37.2189401584201, 118.675793999566 37.2192960611979, 118.67696234809 37.2196964518229, 118.677660861545 37.2201999240451, 118.678177897135 37.2210234917535, 118.678457573785 37.221875, 118.678513454861 37.2228648546007, 118.678331705729 37.2237711588542, 118.678052571615 37.2242727322049, 118.677577853733 37.2247374131944, 118.676701931424 37.2254766167535, 118.676147460938 37.2261447482639, 118.675494791667 37.2269203016493, 118.675146213108 37.2275531684028, 118.67498453776 37.2280523003472, 118.674772677951 37.2288102213542, 118.677125651042 37.2289181857639, 118.680630425347 37.2292857530382, 118.68279812283 37.2300832790799, 118.685833062066 37.2320364040799, 118.688831651476 37.2334483506944, 118.692505696615 37.2349888780382, 118.700428331163 37.2377967664931, 118.704120008681 37.238952094184, 118.707051323785 37.2401380750868, 118.709710557726 37.2412741427951, 118.711365559896 37.2424943033854, 118.71326171875 37.2447810872396, 118.714296603733 37.245651312934, 118.721662597656 37.2496210394965, 118.728425021701 37.2527642144097, 118.735143229167 37.2565700954861, 118.736472710503 37.2571834309896, 118.743666178385 37.261373969184, 118.754669325087 37.2674869791667, 118.759548068576 37.2702964952257, 118.766161295573 37.2736645507812, 118.766655815972 37.2739206271701, 118.771245659722 37.2767540147569, 118.777976888021 37.2801106770833, 118.779711371528 37.2804695638021, 118.782858886719 37.2806361219618, 118.78701171875 37.2802281358507, 118.786977267795 37.2812269422743, 118.806953667535 37.2858113606771, 118.821896701389 37.2887687174479, 118.840726182726 37.2914561631944, 118.845316840278 37.2921034071181, 118.856959092882 37.2938503689236, 119.039890136719 37.3044664171007)";
       // System.out.println("===="+GeometryUtils.validWkt(wkt1));
        //try {
        //    System.out.println(">>>" + GeometryUtils.encodeWkt2Wkb(wkt1,4326));
        //}catch (Exception ex){ex.printStackTrace();}

        //Geometry geometry=GeometryUtils.getLineDistance(GeometryUtils.getGeometry(lineString),50);
        //System.out.println(geometry.toText());
        String id="146MA0BDCP0146M90BDEF0010011";
        System.out.println(new StringBuilder().append(id.substring(0,23)).append("%").append(id.substring(26)).toString());
    }
}
